<?php

namespace App\Http\Middleware;

use App\Yantrana\Components\User\Models\UserAuthorityModel;
use Auth;
use Closure;
use Illuminate\Support\Facades\Route;
use Session;
use URL;

class Authenticate
{
    /**
     * Handle an incoming request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \Closure  $next
     * @param  string[]  ...$guards
     * @return mixed
     *
     * @throws \Illuminate\Auth\AuthenticationException
     */
    public function handle($request, Closure $next)
    {
        $user = Auth::user();
        // check if user is exists
        if (__isEmpty($user) or $user->status !== 1) {
            if ($request->ajax()) {
                return __apiResponse([
                    'message' => __tr('Your account is not in active.'),
                    'auth_info' => getUserAuthInfo(11),
                ], 11);
            }
            // Check if user is logged in then logout that user
            if (Auth::check()) {
                Auth::logout();
            }

            Session::put('intendedUrl', URL::current());

            return redirect()->route('user.login')
                ->with([
                    'error' => true,
                    'message' => __tr('Your account is not in active.'),
                ]);
        }

        if(isDemo()) {
            $includeRoutes = [
                'user.write.setting',
                'user.write.delete_account',
                'user.change_password.process',
                'user.change_email.process',
                'user.write.basic_setting',
                'user.upload_profile_image',
            ];
            $currentRouteName = $request->route()->getName();
            // check if demo mode is on
            if (
                $request->isMethod('post')
                and (in_array($currentRouteName, $includeRoutes))
                and isAdmin() and (getUserID() != 1)
            ) {
                return __apiResponse([
                    'message' => __tr('Functionality is disabled in this demo.'),
                    'show_message' => true,
                ], 1);
            }
        }
        return $next($request);
    }
}
