<?php
/**
* DashboardController.php - Controller file
*
* This file is part of the Dashboard component.
*-----------------------------------------------------------------------------*/

namespace App\Yantrana\Components\Dashboard\Controllers;

use App\Yantrana\Base\BaseController;
use App\Yantrana\Components\Dashboard\DashboardEngine;
use App\Yantrana\Support\CommonUnsecuredPostRequest;

class DashboardController extends BaseController
{
    /**
     * @var  DashboardEngine - Dashboard Engine
     */
    protected $dashboardEngine;

    /**
     * Constructor
     *
     * @param  DashboardEngine  $dashboardEngine - Dashboard Engine
     * @return  void
     *-----------------------------------------------------------------------*/
    public function __construct(DashboardEngine $dashboardEngine)
    {
        $this->dashboardEngine = $dashboardEngine;
    }

    /**
     * Show dashboard view.
     *---------------------------------------------------------------- */
    public function loadDashboardView()
    {
        //fetch dashboard data
        $data = $this->dashboardEngine->prepareDashboard();

        return $this->loadManageView('dashboard.dashboard', $data);
    }
    /**
    * Get Dashboard admin Data
    *
    * @param   CommonUnsecuredPostRequest  $request
    *
    * @return  Array
    */
    public function getDashboardAdminData(CommonUnsecuredPostRequest $request)
    {

        $request->validate([
            'daterange' => [
                'required'
            ]
        ]);

        $prepareAdminDashboardData = $this->dashboardEngine->prepareAdminsDashboardData($request->all());

        // Update client side
        updateClientModels($prepareAdminDashboardData['data']);

        return $this->responseAction(
            $this->processResponse($prepareAdminDashboardData, [], [], true)
        );
    }
}
