<?php

/**
 * ReferralController.php - Controller file
 *
 * This file is part of the User component.
 *-----------------------------------------------------------------------------*/

namespace App\Yantrana\Components\User\Controllers;

use Illuminate\Http\Request;
use App\Yantrana\Base\BaseRequest;
use App\Yantrana\Base\BaseController;

use App\Yantrana\Components\User\ReferralEngine;

class ReferralController extends BaseController
{
    /**
     * @var  ReferralEngine $referralEngine - Referral Engine
     */
    protected $referralEngine;

    /**
     * Constructor
     *
     * @param  ReferralEngine $referralEngine - Referral Engine
     *
     * @return  void
     *-----------------------------------------------------------------------*/
    public function __construct(ReferralEngine $referralEngine)
    {
        $this->referralEngine = $referralEngine;
    }


    /**
     * Referral View
     */
    public function referralView()
    {
        if(getAppSettings('enable_referral_system') == 0) {
            return redirect()->route('dashboard_page');
        }
        return $this->loadPublicView('referral.referral');
    }

    /**
     * Register Referral User
     *
     * @param   Request  $request
     *
     */
    public function registerReferralUser(Request $request)
    {
        if(isLoggedIn()) {
            return redirect()->route('dashboard_page');
        }
        $this->referralEngine->setCookie($request);
        return redirect()->route('user.sign_up');
    }

    /**
     * Get Referral List
     *
     * @return  json object
     */
    public function getReferralList()
    {
        return $this->referralEngine->prepareReferralList();
    }

    /**
     * Referral Users load view.
     *
     * @return json object
     */
    public function referralUsersReadList()
    {
        return $this->loadManageView('referral.list');
    }

    /**
     * Get All Referral List.
     *
     * @return  json object
     */
    public function getAllReferralDataTableList()
    {
        return $this->referralEngine->prepareReferralDataTableList();
    }
}
