<?php

/**
 * ReferralEngine.php - Main component file
 *
 * This file is part of the User component.
 *-----------------------------------------------------------------------------*/

namespace App\Yantrana\Components\User;

use App\Yantrana\Base\BaseEngine;
use App\Yantrana\Components\User\Repositories\ReferralRepository;
use App\Yantrana\Components\User\Interfaces\ReferralEngineInterface;
use Illuminate\Support\Facades\Cookie;
use App\Yantrana\Components\User\UserEngine;

class ReferralEngine extends BaseEngine implements ReferralEngineInterface
{
    /**
     * @var  ReferralRepository $referralRepository - Referral Repository
     */
    protected $referralRepository;

    /**
     * @var  UserEngine $userEngine - User Engine
     */
    protected $userEngine;

    /**
     * Constructor
     *
     * @param  ReferralRepository $referralRepository - Referral Repository
     *
     * @return  void
     *-----------------------------------------------------------------------*/

    public function __construct(ReferralRepository $referralRepository, UserEngine $userEngine)
    {
        $this->referralRepository = $referralRepository;
        $this->userEngine = $userEngine;
    }

    /**
     * Set Cookie
     *
     * @param   object  $request
     * @return  array
     */
    public function setCookie($request)
    {
        $this->storeUserIdInCookie($request);
        return $this->userEngine->prepareUserData($request->get('ref_by'));
    }

    /**
     * Stored User's id In Cookie
     *
     * @param   object  $request
     *
     * @return  void
     */
    public function storeUserIdInCookie($request)
    {
        //store the referred_by user's id
        if ($this->getCookie($request) == null) {
            Cookie::queue('user_referred_by', $request->get('ref_by'), 30 * 24 * 60);
        }
    }

    /**
     * Get Cookie
     *
     * @param   object  $request
     *
     * @return  string
     */
    public function getCookie($request)
    {
        return $request->cookie('user_referred_by');
    }

    /**
     * get Referral list data.
     *
     * @return object
     *---------------------------------------------------------------- */
    public function prepareReferralList()
    {
        $referralCollection = $this->referralRepository->fetchReferralListDataTable();
        $requireColumns = [
          '_id',
            'created_at' => function ($pageData) {
                return formatDate($pageData['user_created_at']);
            },
            'full_name',
        ];

        return $this->dataTableResponse($referralCollection, $requireColumns);
    }


    /**
     * Prepare Referral DataTable List
     *
     * @return object
     */
    public function prepareReferralDataTableList()
    {
        $referralCollection = $this->referralRepository->fetchAllReferralDataTableList();

        $requireColumns = [
          '_id',
          'created_at' => function ($pageData) {
              return formatDate($pageData['created_at']);
          },
          'referred_to_full_name',
          'referred_by_full_name',
          'referred_by_users_username',
          'referred_to_users_username',
        ];

        return $this->dataTableResponse($referralCollection, $requireColumns);
    }
}
