<?php

/**
 * ReferralRepository.php - Repository file
 *
 * This file is part of the User component.
 *-----------------------------------------------------------------------------*/

namespace App\Yantrana\Components\User\Repositories;

use Illuminate\Support\Facades\DB;
use App\Yantrana\Base\BaseRepository;
use App\Yantrana\Components\User\Models\ReferralModel;
use App\Yantrana\Components\User\Models\CreditWalletTransaction;
use App\Yantrana\Components\User\Interfaces\ReferralRepositoryInterface;

class ReferralRepository extends BaseRepository implements ReferralRepositoryInterface
{
    /**
      * @var  CreditWalletRepository - CreditWallet Repository
      */
    protected $creditWalletRepository;
    /**
     * primary model instance
     *
     * @var  object
     */
    protected $primaryModel = ReferralModel::class;


    /**
     * Constructor
     *
     * @param  CreditWalletRepository  $creditWalletRepository - CreditWallet Repository
     * @return  void
     *-----------------------------------------------------------------------*/
    public function __construct(CreditWalletRepository $creditWalletRepository = null)
    {
        if(!$creditWalletRepository) {
            $this->creditWalletRepository = new CreditWalletRepository();
        } else {
            $this->creditWalletRepository = $creditWalletRepository;
        }
    }

    /**
     * Store User Referral Data
     *
     * @param  array  $inputData
     *
     * @return  boolean
     */
    public function storeUserReferral($inputData)
    {
        if($this->storeIt([
            'users__id',
            'by_users__id',
        ], $inputData)) {
            return true;
        };
        return false;
    }

    /**
     * Fetch Referral Data table Data
     *
     * @return  array
     */
    public function fetchReferralListDataTable()
    {
        $dataTableConfig = [
           'searchable' => [
             'full_name' => DB::raw('CONCAT(users.first_name, " ", users.last_name)'),
              'users.created_at'
           ],
        ];

        return $this->primaryModel::leftJoin('users', 'referrals.users__id', '=', 'users._id')
           ->select(
               __nestedKeyValues([
                 'referrals.*',
                 'users' => [
                    DB::raw("CONCAT(COALESCE(first_name, ''), ' ', COALESCE(last_name, '')) AS full_name"),
                    'created_at as user_created_at',
                 ],
            ])
           )
        //    ->whereNotNull('referrals.users__id')
           ->where('referrals.by_users__id', getUserID())
           ->dataTables($dataTableConfig)
           ->toArray();
    }


    /**
     * Fetch All Referrals Data
     *
     * @return Array
     */
    public function fetchAllReferralDataTableList()
    {
        $dataTableConfig = [
           'searchable' => [
             'full_name' => DB::raw('CONCAT(users.first_name, " ", users.last_name)'),
             'referrals.created_at'
           ],
        ];

        return $this->primaryModel::leftJoin('users as referred_to_users', 'referrals.users__id', '=', 'referred_to_users._id')
        ->join('users as referred_by_users', 'referrals.by_users__id', '=', 'referred_by_users._id')
           ->select(
               __nestedKeyValues([
                 'referrals.*',
                 'referred_to_users' => [
                    'username as referred_to_users_username',
                    DB::raw("CONCAT(COALESCE(referred_to_users.first_name, ''), ' ', COALESCE(referred_to_users.last_name , '')) AS referred_to_full_name"),
                 ],
                 'referred_by_users' => [
                    'username as referred_by_users_username',
                    DB::raw("CONCAT(COALESCE(referred_by_users.first_name, ''), ' ', COALESCE(referred_by_users.last_name, '')) AS referred_by_full_name"),
                 ]
            ])
           )
           ->dataTables($dataTableConfig)
           ->toArray();
    }

    /**
     * Get Credits Earned Referral
     *
     * @param   Date  $startDate
     * @param   Date  $endDate
     *
     * @return  int
     */
    public function getCreditsEarnedReferral($startDate, $endDate)
    {
        return CreditWalletTransaction::where(['users__id' => getUserID(), 'credit_type' => 10])//'credit_type' => 10, ==> referral earning
           ->whereBetween('created_at', [$startDate, $endDate])
           ->sum('credits');
    }


    public function hasReferralBonusProcessed($userId, $byUserId)
    {
        return $this->primaryModel::where([
            'users__id' => $userId,
            'by_users__id' => $byUserId
            ])->whereNotNull('credit_wallet_transactions__id')->count();
    }
}
