<?php

namespace App\Yantrana\Support;

use Carbon\Carbon;

/**
 * This CommonTrait class.
 *---------------------------------------------------------------- */
trait CommonTrait
{
    /*
    * Get User Specification Config Items
    *
    * @return boolean.
    *-------------------------------------------------------- */
    public static function getUserSettingConfigItem()
    {
        return require app_path('Yantrana/Components/UserSetting/Config/userSetting.php');
    }

    /*
      * Get User Setting Config Items
      *
      * @return boolean.
      *-------------------------------------------------------- */
    public function getUserSettingConfig()
    {
        return self::getUserSettingConfigItem();
    }

    /**
     * Cast User Settings Value
     *
     * @param  int  $dataType
     * @param  string  $itemValue
     * @return array
     *---------------------------------------------------------------- */
    protected function castValue($dataType, $itemValue)
    {
        switch ($dataType) {
            case 1:
                return (string) $itemValue;
                break;
            case 2:
                return (bool) $itemValue;
                break;
            case 3:
                return (int) $itemValue;
                break;
            case 4:
                return ((! __isEmpty($itemValue)) and (! is_array($itemValue)))
                    ? json_decode($itemValue, true) : $itemValue;
                break;
            case 5:
                return ((! __isEmpty($itemValue)) and (is_array($itemValue)))
                    ? json_encode($itemValue) : '';
                break;
            default:
                return $itemValue;
        }
    }

    /**
     * Prepare Data For Configuration.
     *
     * @param  array  $dbConfigurationSettings
     * @param  array  $defaultSetting
     * @return array
     *---------------------------------------------------------------- */
    protected function prepareDataForConfiguration($dbConfigurationSettings, $defaultSetting)
    {
        $isHideValue = array_get($defaultSetting, 'hide_value', false);
        // Check if a value is hidden for show on view
        if ($isHideValue) {
            return (! __isEmpty(array_get($dbConfigurationSettings, $defaultSetting['key'])))
                ? true : false;
        }

        return array_get($dbConfigurationSettings, $defaultSetting['key'], $defaultSetting['default']);
    }

    /**
     * Get configuration default Settings.
     *
     * @return array
     *---------------------------------------------------------------- */
    protected function getDefaultSettings($configItem)
    {
        $defaultSettings = $configItem;
        // check if default settings exists
        if (__isEmpty($defaultSettings)) {
            return null;
        }

        foreach ($defaultSettings as $settingKey => $settingValue) {
            $defaultSettings[$settingKey]['default'] = $this->castValue($settingValue['data_type'], $settingValue['default']);
        }

        return $defaultSettings;
    }

}
