<?php

use Carbon\Carbon;
use Illuminate\Support\Facades\Http;
use App\Yantrana\Support\CommonTrait;
use App\Yantrana\Components\User\Models\User;
use App\Yantrana\Components\User\Models\UserProfile;
use App\Yantrana\Components\User\Models\ReferralModel;
use App\Yantrana\Components\User\Models\loginLogsModel;
use App\Yantrana\Components\User\Models\UserAuthorityModel;
use App\Yantrana\Components\User\Repositories\{UserRepository};
use App\Yantrana\Components\User\Models\CreditWalletTransaction;
use App\Yantrana\Components\User\Repositories\ReferralRepository;
use App\Yantrana\Components\User\Repositories\LoginLogsRepository;
use App\Yantrana\Components\User\Repositories\CreditWalletRepository;

/*
|--------------------------------------------------------------------------
| App Helpers
|--------------------------------------------------------------------------
|
*/

/**
 * Get the technical items from tech items
 *
 * @param  string  $key
 * @param  mixed  $requireKeys
 * @return mixed
 *-------------------------------------------------------- */
if (!function_exists('configItem')) {
    function configItem($key, $requireKeys = null)
    {
        if (!__isEmpty($requireKeys) and !is_array($requireKeys)) {
            return config('__tech.' . $key . '.' . $requireKeys);
        }

        return array_get(config('__tech'), $key);
    }
}

/**
 * Check if user logged in
 *
 * @return bool
 *---------------------------------------------------------------- */
if (!function_exists('isLoggedIn')) {
    function isLoggedIn()
    {
        return Auth::check();
    }
}

/*
      * Convert date with setting time zone
      *
      * @param string $rawDate
      *
      * @return date
      *-------------------------------------------------------- */

if (!function_exists('appTimezone')) {
    function appTimezone($rawDate)
    {
        $carbonDate = Carbon::parse($rawDate);

        $appTimezone = getAppSettings('timezone');
        if (!__isEmpty($appTimezone)) {
            $carbonDate->timezone = $appTimezone;
        }

        return $carbonDate;
    }
}

/**
 * Get formatted date from passed raw date using timezone
 *
 * @param  string  $rawDateTime
 * @param  string  $format
 * @return date
 *-------------------------------------------------------- */
if (!function_exists('formatDate')) {
    function formatDate($rawDateTime, $format = 'l jS F Y')
    {
        $date = appTimezone($rawDateTime);
        return __tr($date->translatedFormat($format));
    }
}

/**
 * Get formatted date from passed raw date using timezone
 *
 * @param  string  $rawDateTime
 * @param  string  $format
 * @return date
 *-------------------------------------------------------- */
if (!function_exists('formatDiffForHumans')) {
    function formatDiffForHumans($rawDateTime)
    {
        $date = appTimezone($rawDateTime);

        return $date->diffForHumans();
    }
}

/**
 * Get user authentication
 *
 * @return array
 *---------------------------------------------------------------- */
if (!function_exists('getUserAuthInfo')) {
    function getUserAuthInfo($statusCode = null)
    {
        $userAuthInfo = [
            'authorized' => false,
            'reaction_code' => 9,
        ];

        if (Auth::check()) {
            $user = Auth::user();
            $userId = $user->_id;
            // get user profile
            $userProfile = viaFlashCache("current_user_profile_{$userId}_of_user_id", function() use ($user) {
                return UserProfile::where('users__id', $user->_id)->first();
            });
            // get user role
            $userRole = viaFlashCache("current_user_role_{$userId}_of_user_id", function() use ($user) {
                return UserAuthorityModel::join('user_roles', 'user_roles._id', '=', 'user_authorities.user_roles__id')->where([
                    'users__id' => $user->_id,
                ])->select('user_authorities._id AS user_authority_id', 'user_roles._id', 'user_roles.title')->first();
            });

            $authenticationToken = md5(uniqid(true));

            $profilePictureUrl = noThumbImageURL();
            $authUID = authUID();
            $profilePictureFolderPath = getPathByKey('profile_photo', ['{_uid}' => $authUID]);
            $coverPictureUrl = noThumbCoverImageURL();
            $coverPictureFolderPath = getPathByKey('cover_photo', ['{_uid}' => $authUID]);

            if (!__isEmpty($userProfile)) {
                if (!__isEmpty($userProfile->profile_picture)) {
                    $profilePictureUrl = getMediaUrl($profilePictureFolderPath, $userProfile->profile_picture);
                }

                if (!__isEmpty($userProfile->cover_picture)) {
                    $coverPictureUrl = getMediaUrl($coverPictureFolderPath, $userProfile->cover_picture);
                }
            }

            //cover photo
            /*    if (isset($userProfile['cover_picture']) and ! __isEmpty($userProfile['cover_picture'])) {
                   //path
                   $coverPictureFolderPath = getPathByKey('cover_photo', ['{_uid}' => $userUID]);
                   // url
                   $profileInfo['cover_picture_url'] = getMediaUrl($coverPictureFolderPath, $userProfile['cover_picture']);
               } */

            $userAuthInfo = [
                'authorization_token' => $authenticationToken,
                'authorized' => true,
                'reaction_code' => !empty($statusCode) ? $statusCode : 10,
                'profile' => [
                    '_id' => $user->_id,
                    '_uid' => $user->_uid,
                    'username' => !__isEmpty($user) ? $user->username : '',
                    'full_name' => !__isEmpty($user) ? $user->first_name . ' ' . $user->last_name : '',
                    'first_name' => !__isEmpty($user) ? $user->first_name : '',
                    'last_name' => !__isEmpty($user) ? $user->last_name : '',
                    'country' => !__isEmpty($userProfile) ? $userProfile->countries__id : '',
                    'email' => $user->email,
                    'role_id' => $userRole->_id,
                    'role' => $userRole->title,
                    'authority_id' => $userRole->user_authority_id,
                    'profile_picture' => (!__isEmpty($userProfile))
                        ? $userProfile->profile_picture
                        : '',
                    'profile_picture_url' => $profilePictureUrl,
                    'cover_picture_url' => $coverPictureUrl,
                ],
                'personnel' => $user->_id,
                'timezone' => $user->timezone ?? false,
            ];
        }

        if (is_string($statusCode)) {
            return array_get($userAuthInfo, $statusCode, null);
        }

        return $userAuthInfo;
    }
}

/**
 * Get current date time
 *
 * @return void
 *-------------------------------------------------------- */
if (!function_exists('isAdmin')) {
    function isAdmin()
    {
        return (getUserAuthInfo('profile.role_id') == 1) ? true : false;
    }
}

/**
 * Get current date time
 *
 * @return void
 *-------------------------------------------------------- */
if (!function_exists('getCurrentDateTime')) {
    function getCurrentDateTime()
    {
        return new DateTime();
    }
}

/**
 * Check if access social account is valid
 *
 * @param  string  $providerKey
 * @return bool.
 *-------------------------------------------------------- */
if (!function_exists('getSocialProviderName')) {
    function getSocialProviderName($providerKey)
    {
        if (!__ifIsset($providerKey)) {
            return false;
        }

        $socialLoginDriver = config('__tech.social_login_driver');

        if (array_key_exists($providerKey, $socialLoginDriver) !== false) {
            return $socialLoginDriver[$providerKey];
        }

        return false;
    }
}

/**
 * Check if access social account is valid
 *
 * @param  string  $providerKey
 * @return bool.
 *-------------------------------------------------------- */
if (!function_exists('getSocialProviderKey')) {
    function getSocialProviderKey($providerKey)
    {
        if (!__ifIsset($providerKey)) {
            return false;
        }

        $socialLoginDriver = config('__tech.social_login_driver_keys');

        if (array_key_exists($providerKey, $socialLoginDriver)) {
            return $socialLoginDriver[$providerKey];
        }

        return false;
    }
}

/**
 * Auth Uid
 */
if (!function_exists('authUID')) {
    function authUID()
    {
        if (isLoggedIn()) {
            return Auth::user()->_uid;
        }

        return false;
    }
}

/**
 * Auth id
 */
if (!function_exists('getUserID')) {
    function getUserID()
    {
        $user = Auth::user();
        if (!__isEmpty($user)) {
            return $user->_id;
        }

        return null;
    }
}

/**
 * Auth uid
 */
if (!function_exists('getUserUID')) {
    function getUserUID()
    {
        if (isLoggedIn()) {
            return Auth::user()->_uid;
        }

        return false;
    }
}



/**
 * get setting items
 *
 * @param  string  $name
 * @return void
 *---------------------------------------------------------------- */
if (!function_exists('getAppSettings')) {
    function getAppSettings($itemName, $itemKeys = null)
    {
        if ($itemKeys) {
            return  Arr::get(getAppSettings($itemName), $itemKeys);
        }

        $appSettings = [];

        try {
            $configurationSettings = viaFlashCache('app_settings', function () {
                return \App\Yantrana\Components\Configuration\Models\ConfigurationModel::select('name', 'value', 'data_type')->get();
            });
        } catch (\Throwable $th) {
            return null;
        }

        // check if configuration settings exists in db
        if (!__isEmpty($configurationSettings)) {
            foreach ($configurationSettings as $configurationSetting) {
                $appSettings[$configurationSetting->name] = $configurationSetting->value;
            }
        }

        unset($configurationSettings);

        $storeConfiguration = $appSettings;

        // Fetch default setting
        $defaultSettings = config('__settings.items');

        // check if default setting is empty
        if (__isEmpty($defaultSettings)) {
            return null;
        }

        // Loop over default items for finding item default value
        foreach ($defaultSettings as $defaultSetting) {
            // Check if item name exists in default settings
            if (array_key_exists($itemName, $defaultSetting)) {
                // check if requested item exists in store configuration array
                if (array_key_exists($itemName, $storeConfiguration)) {
                    switch ($defaultSetting[$itemName]['data_type']) {
                        case 1:
                            return (string) $storeConfiguration[$itemName];
                            break;
                        case 2:
                            return (bool) $storeConfiguration[$itemName];
                            break;
                        case 3:
                            return (int) $storeConfiguration[$itemName];
                            break;
                        case 4:
                            return array_merge(
                                (is_array($defaultSetting[$itemName]['default']) ? $defaultSetting[$itemName]['default'] : []),
                                json_decode($storeConfiguration[$itemName], true)
                            );
                            break;
                        default:
                            return $storeConfiguration[$itemName];
                            break;
                    }
                }
                // Return default value
                return $defaultSetting[$itemName]['default'];
            }
        }

        // Check if request for logo image url
        if ($itemName == 'logo_image_url') {
            $logoName = getAppSettings('logo_name');
            if($logoName == 'initial-logo.svg') {
                return asset('imgs/' . configItem('logo_name'));
            }
            $logoFilePath = getPathByKey('logo') . '/' . $logoName;
            return getMediaUrl($logoFilePath);
        }

        // Check if request for small logo image url
        if ($itemName == 'small_logo_image_url') {
            $smallLogoName = getAppSettings('small_logo_name');
            if($smallLogoName == 'initial-small-short.svg') {
                return asset('imgs/' . configItem('small_logo_name'));
            }
            $smallLogoFilePath = getPathByKey('small_logo') . '/' . $smallLogoName;
            return getMediaUrl($smallLogoFilePath);
        }

        // Check if request for favicon url
        if ($itemName == 'favicon_image_url') {
            $faviconName = getAppSettings('favicon_name');
            if($faviconName == 'initial-favicon.ico') {
                return asset('imgs/' . configItem('favicon_name'));
            }
            $faviconFilePath = getPathByKey('favicon') . '/' . $faviconName;
            return getMediaUrl($faviconFilePath);
        }

        return null;
    }
}

/**
 * get user setting items
 *
 * @param  string  $name
 * @return void
 *---------------------------------------------------------------- */
if (!function_exists('getUserSettings')) {
    function getUserSettings($itemName, $userID = null)
    {
        //if user is not exist then user loggedIn user id
        if (__isEmpty($userID)) {
            $userID = getUserID();
        }
        // extracted via in memory cache to avoid repeated queries
        $userSettingConfiguration = viaFlashCache("user_settings_of_user_{$userID}_of_{$itemName}_key", function() use ($userID, $itemName) {
            return \App\Yantrana\Components\UserSetting\Models\UserSettingModel::select('key_name', 'value', 'data_type')->where([
                'users__id' => $userID,
                'key_name' => $itemName,
            ])->get();
        });

        // check if configuration settings exists in db
        if (!__isEmpty($userSettingConfiguration)) {
            $storeUserSettings = [];
            foreach ($userSettingConfiguration as $userSetting) {
                $storeUserSettings[$userSetting->key_name] = $userSetting->value;
            }

            // check if requested item exists in store configuration array
            if (array_key_exists($itemName, $storeUserSettings)) {
                return $storeUserSettings[$itemName];
            }
        }

        return null;
    }
}

/**
 * Generate currency array.
 *
 * @param  string  $pageType
 * @param  array  $inputData
 * @return array
 *---------------------------------------------------------------- */
if (!function_exists('combineArray')) {
    function combineArray(&$defaultArray, &$dbArray)
    {
        $merged = $defaultArray;

        foreach ($dbArray as $key => &$value) {
            if (is_array($value) && isset($merged[$key]) && is_array($merged[$key])) {
                $merged[$key] = combineArray($merged[$key], $value);
            } else {
                $merged[$key] = $value;
            }
        }

        return $merged;
    }
}

/**
 * Get Media Path
 *
 * @param  string  $name
 * @return void
 *---------------------------------------------------------------- */
if (!function_exists('getMediaUrl')) {
    function getMediaUrl($storagePath, $filename = '')
    {
        // Check if already URL is given then return URL
        if (starts_with($filename, ['http://', 'https://'])) {
            return $filename;
        }
        // check if filename not exists
        if ($filename) {
            $separator = '/';
            if (substr($storagePath, -1) == '/') {
                $separator = '';
            }
            $storagePath .= $separator . $filename;
        }

        $currentFileSystemDriver = config('filesystems.default', 'public-media-storage');
        // check if current file system driver is public
        if ($currentFileSystemDriver == 'public-media-storage') {
            return asset($storagePath);
            if ($currentFileSystemDriver == 'do_s3_space') {
                return configItem('do_full_url') ? configItem('do_full_url') . $storagePath : config("filesystems.disks.$currentFileSystemDriver.url") . '/' . $storagePath;
            }
        } else {
            return config("filesystems.disks.$currentFileSystemDriver.url") . '/' . $storagePath;
        }

        return null;
    }
}

/**
 * Return image or No image thumbnail
 *
 * @return string
 *-------------------------------------------------------- */
if (!function_exists('imageOrNoImageAvailable')) {
    function imageOrNoImageAvailable($image = '')
    {
        if ($image) {
            return $image;
        }

        return noThumbImageURL();
    }
}

/**
 * Get no thumb image URL
 *
 * @return string
 *-------------------------------------------------------- */
if (!function_exists('noThumbImageURL')) {
    function noThumbImageURL()
    {
        return asset('/imgs/no_thumb_image.jpg');
    }
}

/**
 * Get no thumb image URL
 *
 * @return string
 *-------------------------------------------------------- */
if (!function_exists('noThumbCoverImageURL')) {
    function noThumbCoverImageURL()
    {
        return asset('/imgs/no_thumb_image.jpg');
    }
}

/**
 * check if url
 *
 * @return string
 *-------------------------------------------------------- */
if (!function_exists('isImageUrl')) {
    function isImageUrl($url)
    {
        if (filter_var($url, FILTER_VALIDATE_URL)) {
            return true;
        }

        return false;
    }
}

/**
 * return formatted price
 *
 * @param  float  $amount
 * @return float
 *---------------------------------------------------------------- */
if (!function_exists('priceFormat')) {
    function priceFormat($amount = null, $currencyCode = false, $currencySymbol = false, $options = [])
    {
        $currencySymbol = getCurrencySymbol();

        $formattedCurrency = html_entity_decode($currencySymbol) . number_format((float) $amount, 2) . ($currencyCode == true ? ' ' . getCurrency() : '');

        return __tr($formattedCurrency, [], false);
    }
}

/**
 * get set currency
 *
 * @return string
 *---------------------------------------------------------------- */
if (!function_exists('getCurrency')) {
    function getCurrency()
    {
        return html_entity_decode(getAppSettings('currency_value'));
    }
}

/**
 * get set currency Symbol
 *
 * @return string
 *---------------------------------------------------------------- */
if (!function_exists('getCurrencySymbol')) {
    function getCurrencySymbol()
    {
        return html_entity_decode(getAppSettings('currency_symbol'));
    }
}

/**
 * total user credit data
 *
 * $isLocaleFormat bool
 *
 * @return string
 *---------------------------------------------------------------- */
if (!function_exists('totalUserCredits')) {
    function totalUserCredits(bool $isLocaleFormat = false, $specificItem = null)
    {
        $userId = getUserID();
        $currentDateTime = Carbon::now();
        //get wallet transaction data
        $walletTransactions = viaFlashCache("current_user_{$userId}_wallet_txn_{$currentDateTime}", function() use ($userId) {
            return CreditWalletTransaction::where('users__id', $userId)->get();
        });
        //get wallet credits array
        $credits = array_sum($walletTransactions->pluck('credits')->toArray());
        $totalWordsBalance = floor($credits / getAppSettings('per_word_pricing'));
        $totalSpeechWordsBalance = floor($credits / getAppSettings('text_to_speech_pricing'));
        $imagePrices = getAppSettings('image_pricing');
        $imagePricesFormatted = '';
        Arr::map($imagePrices, function ($elementValue, $elementKey) use ($credits, &$imagePricesFormatted) {
            $imagePricesFormatted .= __tr("__priceSizeValue__ images of __priceSizeKey__ size, ", [
                '__priceSizeKey__' => $elementKey,
                '__priceSizeValue__' => floor($credits / $elementValue),
            ]);
        });
        $totalImageAnimationsBalance = floor($credits / getAppSettings('image_animation_pricing'));
        $totalSecondsAvailableForSpeechToText = floor($credits / getAppSettings('speech_to_text_pricing'));
        //  update client models
        updateClientModels([
            'totalUserCredits' => $credits,
            'totalUserCreditsFormatted' => __tr($credits),
            'totalWordsBalanceFormatted' => __tr($totalWordsBalance),
            'totalSpeechWordsBalanceFormatted' => __tr($totalSpeechWordsBalance),
            'totalImagesBalanceFormatted' => __tr($imagePricesFormatted),
            'totalImageAnimationsBalanceFormatted' => __tr($totalImageAnimationsBalance),
            'totalSecondsAvailableForSpeechToTextFormatted' => __tr($totalSecondsAvailableForSpeechToText),
        ]);
        $itemsCollection = [
            'words' =>  $totalWordsBalance,
            'images' =>  $imagePricesFormatted,
            'imageAnimations' =>  $totalImageAnimationsBalance,
            'speechToTextSeconds' =>  $totalSecondsAvailableForSpeechToText,
            'textToSpeechWords' =>  $totalSpeechWordsBalance,
        ];
        if($isLocaleFormat) {
            if(array_key_exists($specificItem, $itemsCollection)) {
                return __tr($itemsCollection[$specificItem]);
            }
            return __tr($credits);
        }
        if(array_key_exists($specificItem, $itemsCollection)) {
            return $itemsCollection[$specificItem];
        }
        //sum total credits
        return $credits;
    }
}

/**
 * Add activity log entry
 *
 * @param  string  $activity
 * @return void.
 *-------------------------------------------------------- */
if (!function_exists('activityLog')) {
    function activityLog($activity)
    {
        App\Yantrana\Components\User\Models\ActivityLog::create([
            'created_at' => Carbon::now(),
            'user_id' => getUserID(),
            '__data' => $activity,
        ]);
    }
}

/**
 * Get restriction for media
 *
 * @param  string  $activity
 * @return void.
 *-------------------------------------------------------- */
if (!function_exists('getMediaRestriction')) {
    function getMediaRestriction($mediaType, $encoded = true)
    {
        $mediaConfiguration = config('yes-file-storage.element_config');
        $allowedExtension = array_get($mediaConfiguration, $mediaType, null);
        // Check if allowed extension exists
        if (!__isEmpty($allowedExtension)) {
            $mediaRestriction = array_get($allowedExtension, 'restrictions.allowedFileTypes');
            if ($encoded) {
                return json_encode($mediaRestriction);
            }

            return $mediaRestriction;
        }

        return false;
    }
}

/**
 * activate sidebar link by alias
 *
 * @param  string  $alias
 *-----------------------------------------------------------------------*/
if (!function_exists('makeLinkActive')) {
    function makeLinkActive($alias, $routeName = null, $className = 'active', $elseClass = '')
    {
        if(is_array($alias)) {
            if(route($alias['name'], $alias['parameters']) == request()->url()) {
                return " $className ";
            }
        } else {
            if(!$routeName) {
                $routeName = Route::getCurrentRoute()->getName();
            }

            if ($routeName == $alias) {
                return " $className ";
            }
        }
        return " $elseClass ";
    }
}

/**
 * activate sidebar link by alias
 *
 * @param  string  $alias
 *-----------------------------------------------------------------------*/
if (!function_exists('getPhotosFromAPI')) {
    function getPhotosFromAPI($page = 1)
    {
        $url = strtr('https://picsum.photos/v2/list?page=__page__&limit=100', [
            '__page__' => $page,
        ]);

        $response = Http::get($url);
        $result = $response->body();

        return json_decode(($result), true);
    }
}

/**
 * Get demo mode for Demo of site
 *
 * @return boolean.
 *-------------------------------------------------------- */
if (!function_exists('isDemo')) {
    function isDemo()
    {
        return (config('__tech.is_demo_mode', false)) ? true : false;
    }
}

/**
 * Get the technical items from tech items
 *
 * @param  string  $key
 * @param  mixed  $requireKeys
 * @return mixed
 *-------------------------------------------------------- */
if (!function_exists('slugIt')) {
    function slugIt($title, $separator = '-')
    {
        // Convert all dashes/underscores into separator
        $flip = $separator == '-' ? '_' : '-';

        $title = preg_replace('![' . preg_quote($flip) . ']+!u', $separator, $title);

        // Replace all separator characters and whitespace by a single separator
        $title = preg_replace('![' . preg_quote($separator) . '\s]+!u', $separator, $title);

        return strtolower(trim($title, $separator));
    }
}
/**
 * Check request coming from mobile app
 *
 * @return number.
 *-------------------------------------------------------- */
if (!function_exists('isMobileAppRequest')) {
    config([
        'app.api_request_signature' => request()->header('Api-Request-Signature'),
    ]);
    function isMobileAppRequest()
    {
        //Check request coming from mobile app
        if (config('app.api_request_signature') === 'mobile-app-request') {
            return true;
        }

        return false;
    }
}

/**
 * sets the Authentication token (jwt)
 *
 * @return boolean.
 *-------------------------------------------------------- */
if (!function_exists('setAccessToken')) {
    function setAccessToken($token)
    {
        //set token
        config(['app.additional' => [
            'token_refreshed' => $token,
        ]]);
    }
}

/**
 * Get active translation languages
 *
 * @return array.
 *-------------------------------------------------------- */
if (!function_exists('getActiveTranslationLanguages')) {
    function getActiveTranslationLanguages()
    {
        $translationLanguages = getAppSettings('translation_languages');
        if (__isEmpty($translationLanguages)) {
            $translationLanguages = [];
        }
        $translationLanguages[config('__tech.default_translation_language.id', 'en_US')] = configItem('default_translation_language');

        return array_where($translationLanguages, function ($languageItem) {
            if ($languageItem['status'] !== false) {
                return $languageItem;
            }
        });
    }
}

/**
 * Get and Set credit package id for in app purchase product ID
 *-----------------------------------------------------------------------*/
if (!function_exists('toggleProductId')) {
    function toggleProductId(string $uid)
    {
        if(str_contains($uid, '_')) {
            return str_replace('_', '-', $uid);
        }
        return str_replace('-', '_', $uid);
    }
}


/**
 * Country code
 *
 * @return bool
 *---------------------------------------------------------------- */
if (!function_exists('getCountryPhoneCodes')) {
    function getCountryPhoneCodes()
    {
        return \App\Yantrana\Support\Country\Models\Country::select('name', 'phone_code')->whereNotNull('phone_code')->whereNot('phone_code', 0)->get()->toArray();
    }
}

/**
 * Explode mobile number as array of country code and mobile number
 *
 * @return bool
 *---------------------------------------------------------------- */
if (!function_exists('explodeMobileNumber')) {
    function explodeMobileNumber($rawMobileNumber)
    {
        $withoutCodeMblNo = explode('-', $rawMobileNumber);
        $mobileNumber = isset($withoutCodeMblNo[1]) ? $withoutCodeMblNo[1] : '';
        $countryCode = explode('0', $withoutCodeMblNo[0]);
        $countryPhnCode = isset($countryCode[1]) ? ($countryCode[1]) : '';

        return [
            'country_code' => $countryPhnCode,
            'mobile_number' => $mobileNumber
        ];
    }
}

/**
 * Get Max age date carbon object
 *
 * @return Carbon object
 *---------------------------------------------------------------- */
if (!function_exists('getAgeDate')) {
    function getAgeDate($age, $ageType = 'min', $isForSearch = false)
    {
        if($ageType == 'min') {
            return Carbon::today()->subYears($age);
        }
        return Carbon::today()->subYears($age + ($isForSearch ? 1 : 0))->endOfDay();
    }
}

if (!function_exists('getPromptTemplates')) {
    /**
     * Get the prompt templates
     *
     * @param string|null $specificItem
     * @return mixed
     */
    function getPromptTemplates(string $specificItem = null, string $sectionItem = null, $options = [])
    {
        $options = array_merge([
            'with_total_count' => false,
            'gettext' => true,
        ], $options);
        try {
            $templates = viaFlashCache('template_collection_file' . $options['gettext'], function () use ($options) {
                if(!$options['gettext']) {
                    $cachedLocale = config('app.locale');
                    changeAppLocale('en_US');
                }
                $templates = require app_path('Yantrana/Components/Prompt/Support/text-prompt-collections.php');
                if(!$options['gettext']) {
                    changeAppLocale($cachedLocale);
                }
                return $templates;
            });
            $totalTemplateCount = 0;
            $templates = array_filter($templates, function ($k) {
                return $k ? true : false;
            }, ARRAY_FILTER_USE_KEY);

            foreach ($templates as $templateCategoryKey => $templateCategory) {
                $templates[$templateCategoryKey]['template_count'] = 0;
                if (isset($templateCategory['templates'])) {
                    // sort the templates by title
                    $templates[$templateCategoryKey]['templates'] = collect($templateCategory['templates'])->sortBy('slug')->toArray();
                    $categoryTemplateCount = count($templates[$templateCategoryKey]['templates']);
                    $totalTemplateCount += $categoryTemplateCount;
                    $templates[$templateCategoryKey]['template_count'] = $categoryTemplateCount;
                }
            }
            // sort the template categories by title
            $templates = collect($templates)->sortBy('slug')->toArray();

            if(!$specificItem and !$sectionItem) {
                if($options['with_total_count']) {
                    return [
                        'templates' => $templates,
                        'totalTemplateCount' => $totalTemplateCount,
                    ];
                }
                return $templates;
            }
            $templatesFound =  Arr::get($templates, $specificItem);
            if($specificItem and !$sectionItem) {
                return $templatesFound;
            }
            if($sectionItem) {
                $templateItems = [];
                foreach ($templatesFound as $value) {
                    if(!isset($value['templates'])) {
                        continue;
                    }
                    if (Arr::has($value['templates'], $sectionItem)) {
                        $templateItems = Arr::get($value['templates'], $sectionItem);
                        break;
                    }
                }
                unset($sectionItem,$templates);
                return $templateItems;
            }
        } catch (\Throwable $th) {
            return [];
        }
    }
}

if (!function_exists('prepareInputFieldData')) {
    /**
     * Process and Prepare Input field data
     *
     * @param array $field
     * @return array
     */
    function prepareInputFieldData($field)
    {
        return array_merge([
            'title' => '',
            'type' => 'text',
            'default' => '',
            'validations' => [],
        ], $field);
    }
}
if (!function_exists('getPromptLanguages')) {
    /**
     * Get the prompt Languages
     *
     * @param string|null $languageCode
     * @return array
     */
    function getPromptLanguages($languageCode = null)
    {
        $languages = require app_path('Yantrana/Components/Prompt/Support/prompt-response-language.php');
        if(!$languageCode) {
            return $languages;
        }
        return Arr::get($languages, $languageCode);
    }
}

if (!function_exists('storeReferralWalletTransaction')) {
    /**
     * Store new wallet transaction entry for user who referred by and referred to.
     *
     * @param  array  $inputData
     * @return boolean
     *---------------------------------------------------------------- */
    function storeReferralWalletTransaction($userId, $byUserId = null)
    {
        if($byUserId == null) {
            $referralData = ReferralModel::where('users__id', $userId)->first();
            if(!__isEmpty($referralData)) {
                $byUserId = $referralData->by_users__id;
            }
        }

        if(!$byUserId or !$userId) {
            return false;
        }
        $referralRepo = new ReferralRepository();
        $hasReferralBonusProcessed = $referralRepo->hasReferralBonusProcessed($userId, $byUserId);
        if($hasReferralBonusProcessed) {
            return false;
        }
        if (getAppSettings('give_bonus', 'referred_to') != 0) {
            $keyValues = [
                'status' => 1, // completed
                'users__id' => $userId,
                'credits' =>  getAppSettings('give_bonus', 'referred_to'),
                'credit_type' => 9, // Referral Bonus credits
                'description' => 'Referral Bonus'
            ];

            $creditWalletRepo = new CreditWalletRepository();

            if($creditWalletTransaction = $creditWalletRepo->storeIt($keyValues)) {
                // update referral
                $referralRepo->updateIt([
                    'users__id' => $userId,
                    'by_users__id' => $byUserId
                ], [
                    'credit_wallet_transactions__id' => $creditWalletTransaction->_id
                ]);
            }
        }

        if (getAppSettings('give_bonus', 'referred_by') != 0) {
            $keyValues = [
                'status' => 1, // completed
                'users__id' => $byUserId,
                'credits' =>  getAppSettings('give_bonus', 'referred_by'),
                'credit_type' => 10, // referral earning
                'description' => 'Referral Earning'
            ];

            if($creditWalletTransaction = $creditWalletRepo->storeIt($keyValues)) {
                // update referral
                $referralRepo->updateIt([
                    'users__id' => $userId,
                    'by_users__id' => $byUserId
                ], [
                    'by_credit_wallet_transactions__id' => $creditWalletTransaction->_id
                ]);
            }

            // return false;   // on failed
        }

        return true; //default
    }
}

/**
 * get user setting items
 *
 * @param  string  $name
 * @return bool
 *---------------------------------------------------------------- */
if (!function_exists('isFeatureAvailable')) {
    function isFeatureAvailable($itemName)
    {
        $retrieveFromDb = getAppSettings('features_availability_users_settings', $itemName);
        if(!$retrieveFromDb) {

        }
    }
}

/**
 * determine icon type and display
 *
 * @param  string  $item
 * @param  string  $additionalClasses
 * @return string
 *---------------------------------------------------------------- */
if (!function_exists('processIconDisplay')) {
    function processIconDisplay(&$item, $additionalClasses = [])
    {
        $additionalClasses = array_merge([
            'fa' => '',
            'http' => '',
            'other' => '',
        ], $additionalClasses);
        if(isset($item['icon']) and !__isEmpty($item['icon'])) {
            if(Str::startsWith($item['icon'], 'fa')) {
                return "<i class='{$additionalClasses['fa']} {$item['icon']}'></i>";
            } elseif(Str::startsWith($item['icon'], 'http')) {
                return "<img src='{$item['icon']}' class='lw-list-item-icon {$additionalClasses['http']}' alt='{$item['title']}'>";
            }
            $assetUrl = asset("imgs/icons/{$item['icon']}");
            return "<img src='{$assetUrl}' class='lw-list-item-icon {$additionalClasses['other']}' alt='{$item['title']}'>";
        }
        return '';
    }

    /**
     * Get the random featured image
     *
     * @return string
     *---------------------------------------------------------------- */
    if (!function_exists('getRandomFeaturedImageUrl')) {
        function getRandomFeaturedImageUrl()
        {
            return __yesset('imgs/home/random/*.{jpg,png}', false, ['random' => true, 'multiple_extensions' => true]);
        }
    }
}
