@section('page-title', __tr("AI Image Generation"))
@section('head-title', __tr("AI Image Generation"))
@section('keywordName', strip_tags(__tr("AI Image Generation")))
@section('keyword', strip_tags(__tr("AI Image Generation")))
@section('description', strip_tags(__tr("AI Image Generation")))
@section('keywordDescription', strip_tags(__tr("AI Image Generation")))
@section('page-image', getAppSettings('logo_image_url'))
@section('twitter-card-image', getAppSettings('logo_image_url'))
@section('page-url', url()->current())

<!-- Page Heading -->
<div class="d-sm-flex align-items-center justify-content-between mb-4 lw-page-header">
    <h1 class="h3 mb-0 text-gray-200">
        {{ __tr("AI Image Generation") }}
    </h1>
    {{-- history button --}}
   <a class="btn btn-dark btn-sm lw-ajax-link-action lw-action-with-url" href="{{ route('manage.history',[
    'historyType' => 'image'
]) }}"><i class="fa fa-history" aria-hidden="true"></i> <?= __tr('Image Generation History') ?></a>
   {{-- /history button --}}
</div>
<div class="row">
    <div class="col">
        @include('user.generator.partials.remaining-credits-partial', ['contentType' => 'image'])
    </div>
</div>
<div class="row" x-data="{numberOfImagesRequested:1, showImageLoader:false}">
    <!-- Start of Page Wrapper -->
        <div class="col-md-4 mb-4">
            <!-- card -->
            <div class="card mb-4">
                <div class="card-body">
                    <form method="post" data-event-stream-update="true" action="{{ route('image.generator') }}" class="lw-ajax-form lw-image-generator-block" data-pre-callback="onImageGenerationPreCallback" data-callback="onImageGenerationSuccessCallback" data-show-processing="true">
                    <div class="form-group">
                        <label for="lwDescribeImage">
                            <?= __tr('Description') ?>
                        </label>
                        <textarea id="lwDescribeImage" type="text" class="form-control lw-image-generator-field" name="query" placeholder="{{ __tr("Describe image you want to generate") }}" required></textarea>
                    </div>
                    <div class="form-group">
                        <label for="lwImageVariations">
                            <?= __tr('Variations') ?>
                        </label>
                        <select x-model="numberOfImagesRequested" name="no_of_images" class="form-control lw-ai-model-select custom-select" id="lwImageVariations" required>
                            @for($i = 1; $i <= configItem('no_of_images'); $i++) <option value="{{ $i }}">{{ __tr($i) }}</option>@endfor
                        </select>
                    </div>
                        <div class="form-group mt-2">
                            <label for="lwStylePreset">
                                <?= __tr('Style') ?>
                            </label>
                            <select name="style_preset" class="form-control lw-ai-model-select custom-select" id="lwStylePreset"
                                required>
                                @foreach (configItem('style_preset') as $key => $style)
                                <option value="{{ $key }}">{{ $style }}</option>
                                @endforeach
                            </select>
                        </div>
                        @if(getAppSettings('enable_open_ai') and array_key_exists(getAppSettings('ai_image_generation_model'), configItem('open_ai.models.dall_e')))
                            <div class="form-group mt-2">
                                <label for="lwOpenAiImageSize"><?= __tr('Image Size') ?></label>
                                <select name="open_ai_image_size" class="form-control lw-ai-model-select custom-select" id="lwOpenAiImageSize"
                                    required>
                                    @foreach (configItem('open_ai.image_size') as $key => $image_size)
                                    <option value="{{ $image_size }}">{{ __tr($image_size) }}</option>
                                    @endforeach
                                </select>
                            </div>
                        @endif
                        @if(getAppSettings('allow_stable_diffusion_ai') and array_key_exists(getAppSettings('ai_image_generation_model'), configItem('stable_diffusion_ai.models.text_to_image_generation')))
                        @php
                            $size = configItem("stable_diffusion_ai.models.text_to_image_generation.". getAppSettings('ai_image_generation_model') .".size");
                        @endphp
                            <div class="alert alert-info">{{  __tr("Image will be generated in $size x $size size.") }}</div>
                        @endif
                        <div class="form-group">
                            <button type="submit" class="btn btn-light">
                                <?= __tr('Generate') ?>
                            </button>
                        </div>
                </form>
                </div>
            </div>
            <!-- /card -->
        </div>
    <!-- End of Page Wrapper -->
    <div class="lw-generator-content col-md-8">
        <div x-data="{ aiGeneratedResponseError: '' }">
            <template x-if="aiGeneratedResponseError.length > 1">
                <div class="alert alert-danger alert-dismissible fade show" x-cloak x-text="aiGeneratedResponseError">
                </div>
            </template>
        </div>

        <div x-show="showImageLoader" class="row row-cols-1 row-cols-md-3 row-cols-lg-3 g-4" >
                <template x-for="i in Number(numberOfImagesRequested)" :key="index">
                    <div class="col">
                        <div class="card ">
                            <img src="{{ __yesset('imgs/image-load-animation.gif') }}" class="card-img-top lw-photoswipe-gallery-img" alt="...">
                            {{-- Download Image --}}
                            <div class="card-footer text-center">
                            <a class=" btn btn-muted disabled" href="#" disabled title="{{ __tr('Download') }}">{{  __tr('Download') }} <i class="fas fa-download"></i></a>
                        </div>
                           {{-- /Download Image --}}
                    </div>
            </div>
            </template>
        </div>
        <div x-show="!showImageLoader" class="row row-cols-1 row-cols-md-3 row-cols-lg-3 g-4" x-data="{ aiGeneratedResponse: [] }">
                <template x-for="(generatedImage, index) in aiGeneratedResponse.generatedImages" :key="index">
                    <div class="col">
                        <div class="card">
                            <img :src="generatedImage.url" class="card-img-top lw-photoswipe-gallery-img" alt="...">
                            {{-- Download Image --}}
                            <a class="card-footer btn btn-primary" :href="__Utils.apiURL('<?= route('user.download.result_file', ['recordUid' => 'recordUid', 'filename' => 'filename']) ?>', {'recordUid': aiGeneratedResponse._uid, 'filename' : generatedImage.filename})" title="{{ __tr('Download') }}">{{  __tr('Download') }} <i class="fas fa-download"></i></a>
                            {{-- /Download Image --}}
                        </div>
                </div>
            </template>
        </div>
    </div>