<?php
    $historyType = request()->historyType;
    $imageAnimationMediaUrl = '';
    $audioMediaUrl = '';
    $speechAudioUrl = '';
    if(!isset($isForAllUsers)) {
        $isForAllUsers = false;
        $datatableUrl = route('user.history.list',[
            'historyType' => $historyType
        ]);
        $imageAnimationMediaUrl = getMediaUrl(getPathByKey('image_animation', ['{_uid}' => authUID()])) . DIRECTORY_SEPARATOR;
        $audioMediaUrl = getMediaUrl(getPathByKey('speech_audio', ['{_uid}' => authUID()])) . DIRECTORY_SEPARATOR;
        $speechAudioUrl = getMediaUrl(getPathByKey('generated_speech', ['{_uid}' => authUID()])) . DIRECTORY_SEPARATOR;
    } else {
        $datatableUrl = route('all.users.history.list',[
            'historyType' => $historyType
        ]);
    }
?>
<!-- Start of History Wrapper -->
<div class="card mb-4">
    <div class="card-body">
        <ul class="nav nav-tabs mb-3">
            @php
            $generatorFeatures = configItem('generator_type_features');
            @endphp
            @foreach(configItem('generator_type') as $key => $value)
            @if(getAppSettings('features_availability_users_settings', $generatorFeatures[$key]) == 1)
                <!-- generator_type -->
                <li class="nav-item">
                    <a class="nav-link lw-ajax-link-action lw-action-with-url <?= $historyType == $key ? 'active' : '' ?>" data-title="{{ $value }}"
                        href="{{ $isForAllUsers ? route('manage.users.history',['historyType' => $key]) : route('manage.history',['historyType' => $key]) }}">
                        <?= $value ?>
                    </a>
                </li>
                <!--/ generator_type -->
                @endif
            @endforeach
        </ul>
        <x-lw.datatable id="lwHistoryTableNew" :url="$datatableUrl" data-callback="audioColumnTemplateProcess">
            @if($isForAllUsers)
                <th data-orderable="true" data-template="#userNameColumnTemplate" name="null"><?= __tr('Full Name') ?></th>
            @endif
            <th data-order-by="true" data-order-type="desc" data-orderable="true"  data-name="created_at"><?= __tr('Requested on') ?></th>
            @if(in_array($historyType, [
                'text',
                'code',
                'image',
                'translation',
                'text-to-speech',
            ]))
            <th data-name="prompt"><?= __tr('Prompt') ?></th>
            @endif
            @if(in_array($historyType, [
                'speech-to-text',
            ]))
            <th data-template="#sourceAudioColumnTemplate" name="null"><?= __tr('Source Speech Audio') ?></th>
            @endif
            @if(in_array($historyType, [
                'text-to-speech',
            ]))
            <th data-template="#resultAudioColumnTemplate" name="null"><?= __tr('Result Speech') ?></th>
            @endif
            @if(in_array($historyType, [
                'image-animation'
            ]))
            <th data-template="#animationThumbnailActionColumnTemplate" name="null"><?= __tr('Source Image') ?></th>
            @endif
            @if(in_array($historyType, [
                'image',
                // 'image-animation'
            ]))
            <th data-template="#thumbnailActionColumnTemplate" name="null"><?= __tr('Result Images') ?></th>
            @endif
            @if($historyType == 'text')
            <th data-name="template"><?= __tr('Template') ?></th>
            @endif
            @if(in_array($historyType, [
                'text',
                'code',
                'translation'
            ]))
            <th data-name="language_code"><?= __tr('Language') ?></th>
            @endif
            <th data-template="#historyActionColumnTemplate" name="null"><?= __tr('Action') ?></th>
        </x-lw.datatable>

<!-- User delete Container -->
<div id="lwHistoryDeleteContainer" style="display: none;">
	<h3><?= __tr('Are You Sure!') ?></h3>
	<?= __tr('You want to delete this history item.') ?>
</div>
<!-- User delete Container -->
{{-- Source audio action --}}
<script type="text/template" id="sourceAudioColumnTemplate">
    <% if(__tData.prompt) { %>
    <div class="lw-audio-player-container">
        <audio width="100%" height="100%">
            <source src="{{ $audioMediaUrl }}<%= __tData.prompt %>">{{ __tr('Your browser does not support the audio tag.') }}
        </audio>
    </div>
    <% } else { %>
        {{  __tr('N/A') }}
    <% } %>
</script>
{{-- /Source audio action --}}
{{-- Result audio action --}}
<script type="text/template" id="resultAudioColumnTemplate">
    <% if(__tData.prompt_response) { %>
    <div class="lw-audio-player-container">
        <audio width="100%" height="100%">
            <source src="{{ $speechAudioUrl }}<%= __tData.prompt_response %>">{{ __tr('Your browser does not support the audio tag.') }}
        </audio>
    </div>
    <% } else { %>
        {{  __tr('N/A') }}
    <% } %>
</script>
{{-- /Result audio action --}}

<!-- History Action Column -->
<script type="text/template" id="historyActionColumnTemplate">
        <!-- manage history Button -->
        <% if((__tData.type != "image") && (__tData.type != "text-to-speech")) { %>
            <a href class="btn btn-primary btn-sm" data-toggle="modal" data-response="<%- __tData.prompt_response %>" data-type="<%= __tData.type %>" data-target="#userHistoryDialog" data-response-user> <?= __tr('View Result') ?></a>
            </a>
            <% } %>
        <% if((__tData.type == "image-animation") || (__tData.type == "text-to-speech")) { %>
            <a class="btn btn-secondary btn-sm" href="<%= __Utils.apiURL("<?= route('user.download.result_file', ['recordUid' => 'recordUid']) ?>", {'recordUid': __tData._uid}) %>"> <i class="fa fa-download"></i> {{  __tr('Download') }}</a>
        <% } %>
        <!-- /manage history Button -->

      @if(isAdmin())
              <!-- history Delete Button -->
		    <a data-callback="onHistoryTableSuccessAction" data-method="post" class="btn btn-danger btn-sm lw-ajax-link-action-via-confirm" data-callback-params="{{ json_encode(['datatableId' => '#lwHistoryTableNew']) }}" data-confirm="#lwHistoryDeleteContainer" href data-action="<%= __Utils.apiURL("<?= route('admin.history.write.delete', ['historyUId' => 'historyUId']) ?>", {'historyUId': __tData._uid}) %>"><i class="fas fa-trash-alt"></i> <?= __tr('Delete') ?></a>
            <!-- /history Delete Button -->
            @else
             <!-- history Delete Button -->
		    <a data-callback="onHistoryTableSuccessAction" data-method="post" class="btn btn-danger btn-sm lw-ajax-link-action-via-confirm" data-callback-params="{{ json_encode(['datatableId' => '#lwHistoryTableNew']) }}" data-confirm="#lwHistoryDeleteContainer" href data-action="<%= __Utils.apiURL("<?= route('user.history.write.delete', ['historyUId' => 'historyUId']) ?>", {'historyUId': __tData._uid}) %>"><i class="fas fa-trash-alt"></i> <?= __tr('Delete') ?></a>
            <!-- /history Delete Button -->
      @endif
</script>
<!-- History Action Column -->

<!-- user ResponseDetails Modal-->
<div class="modal fade" id="userHistoryDialog" tabindex="-1" role="dialog"
    aria-labelledby="userResponseDetailsModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-lg" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="userResponseDetailsModalLabel">
                    <?= __tr('Prompt Response') ?>
                </h5>
                <button class="close" type="button" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body" id="lwUserResponseDetailsContent"></div>
            <script type="text/template" id="lwResponseDetailsDetailTemplate"
                data-replace-target="#lwUserResponseDetailsContent" data-modal-id="#userHistoryDialog">
                <div class="card-body">
                    <% if(__tData.type == "image-animation") { %>
                        <video id="lwAnimationVideo" width="100%" height="100%" loop>
                            <source src="{{ $imageAnimationMediaUrl }}<%= __tData.promptResponse %>" type="video/mp4">{{ __tr('Your browser does not support the video tag.') }}
                        </video>
                    <% } else { %>
                        <pre class="lw-code-block-container"><%= __tData.promptResponse %></pre>
                    <% } %>
                </div>
			</script>
            <!-- modal footer -->
            <div class="modal-footer mt-3">
                <button class="btn btn-light btn-sm" class="close" type="button" data-dismiss="modal">
                    <?= __tr('Close') ?>
                </button>
            </div>
            <!-- modal footer -->
        </div>
    </div>
</div>
<!-- / user Response Details Modal-->

@if($isForAllUsers)
<!-- User Full Name Action Column -->
<script type="text/template" id="userNameColumnTemplate">
    <a href class="" data-toggle="modal" data-user-details='<%= JSON.stringify(__tData.user) %>'  data-type="<%= __tData.type %>" data-target="#userDetailsDialog" data-user-detail></i>
        <%= __tData.full_name %>
    </a>
</script>
<!-- User Full Name Action Column -->

<!-- User Details Dialog -->
<div class="modal fade" id="userDetailsDialog" tabindex="-1" role="dialog" aria-labelledby="userResponseDetailsModalLabel"
    aria-hidden="true">
    <div class="modal-dialog modal-lg" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="userResponseDetailsModalLabel">
                    <?= __tr('User Details') ?>
                </h5>
                <button class="close" type="button" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body" id="lwUserDetailsContent"></div>
            <script type="text/template" id="lwUserDetailsTemplate" data-replace-target="#lwUserDetailsContent" data-modal-id="#userDetailsDialog">
                <div class="card">
                    <div class="card-body">
                        <ul class="list-group ">
                            <span class="d-block p-2 text-white">
                                <div class="mb-2 d-flex">
                                    <div class="">
                                        {{ __tr('First name') }}:
                                    </div>
                                    <span class="ml-3">
                                        <%- __tData.userData.first_name %>
                                    </span>
                                </div>
                            </span>
                            <span class="d-block p-2 text-white">
                                <div class="mb-2 d-flex">
                                    <div class="">
                                        {{ __tr('Last name') }}:
                                    </div>
                                    <span class="ml-3">
                                        <%- __tData.userData.last_name %>
                                    </span>
                                </div>
                            </span>
                            <span class="d-block p-2 text-white">
                                <div class="mb-2 d-flex">
                                    <div class="">
                                        {{ __tr('Username') }}:
                                    </div>
                                    <span class="ml-3">
                                        <%- __tData.userData.username %>
                                    </span>
                                </div>
                            </span>
                            <span class="d-block p-2 text-white">
                                <div class="mb-2 d-flex">
                                    <div class="">
                                        {{ __tr('Email') }}:
                                    </div>
                                    <span class="ml-3">
                                        <%- __tData.userData.email %>
                                    </span>
                                </div>
                            </span>
                            <span class="d-block p-2 text-white">
                                <div class="mb-2 d-flex">
                                    <div class="">
                                        {{ __tr('Mobile Number') }}:
                                    </div>
                                    <span class="ml-3">
                                        <%- __tData.userData.mobile_number %>
                                    </span>
                                </div>
                            </span>
                        </ul>
                    </div>
                </div>
			</script>
            <!-- modal footer -->
            <div class="modal-footer mt-3">
                <button class="btn btn-light btn-sm" class="close" type="button" data-dismiss="modal">
                    <?= __tr('Close') ?>
                </button>
            </div>
            <!-- modal footer -->
        </div>
    </div>
</div>
<!-- User User Details Dialog -->
@endif

<!-- image thumbnail Column -->
<script type="text/template" id="thumbnailActionColumnTemplate">
    <div class="row ">
        <!-- manage image thumbnail -->
        <% _.forEach(__tData.prompt_response, function(imageItem, key) { %>
            <div class="card m-2">
                <img src="<%= imageItem.url %>" class="img-rounded lw-photoswipe-gallery-img lw-history-img-thumbnail" data-img-index="<%= key %>"/>
                <a class="btn btn-block btn-secondary mt-1" title="{{  __tr('Download') }}" href="<%= __Utils.apiURL("<?= route('user.download.result_file', ['recordUid' => 'recordUid', 'filename' => 'filename']) ?>", {'recordUid': __tData._uid, 'filename' : imageItem.filename}) %>"><i class="fa fa-download"></i> </a>
            </div>
        <% }); %>
        <!-- /manage image thumbnail -->
	</div>
</script>
<!-- image thumbnail Column -->
<!-- image animation thumbnail Column -->
<script type="text/template" id="animationThumbnailActionColumnTemplate">
    <div class="btn-group">
        <!-- manage image thumbnail -->
        <img src="<%= __tData.prompt %>" class="img-thumbnail lw-item-img-thumbnail lw-photoswipe-gallery-img mr-2" data-img-index="1"/>
        <!-- /manage image thumbnail -->
	</div>
</script>
<!-- image animation thumbnail Column -->
<!-- End of History Wrapper -->
@lwPush('appScripts')
<script>
    (function($) {
"use strict";
    /*
    Initialize the audio player for audio source
    */
    window.audioColumnTemplateProcess = function (item, other) {
        GreenAudioPlayer.init({
            selector: '.lw-audio-player-container:not(.green-audio-player)', // added not to avoid already initialed items
            stopOthersOnPlay: true,
            showDownloadButton: false,
        });
    };
    //user Response Details dialog details
	__Utils.modalTemplatize('#lwResponseDetailsDetailTemplate', function(e, data) {
        _.defer(function() {
            var lwAnimationVideo = document.getElementById('lwAnimationVideo');
            if(lwAnimationVideo) {
                lwAnimationVideo.load();
                lwAnimationVideo.play();
            }
        });
        return {
            'promptResponse': data['response'],
            'type' : data['type']
        };
    }, function(e, myData) {});
    // Perform actions after delete
	window.onHistoryTableSuccessAction = function(response, params) {
		reloadDT(params.datatableId);
	};
        //user Details dialog
	__Utils.modalTemplatize('#lwUserDetailsTemplate', function(e, data) {
        return {
			'userData': data['userDetails']
		};
	}, function(e, myData) {});
})(jQuery);
</script>
@lwPushEnd