@section('page-title', __tr("Text to Speech"))
@section('head-title', __tr("Text to Speech"))
@section('keywordName', strip_tags(__tr("Text to Speech")))
@section('keyword', strip_tags(__tr("Text to Speech")))
@section('description', strip_tags(__tr("Text to Speech")))
@section('keywordDescription', strip_tags(__tr("Text to Speech")))
@section('page-image', getAppSettings('logo_image_url'))
@section('twitter-card-image', getAppSettings('logo_image_url'))
@section('page-url', url()->current())

<!-- Page Heading -->
<div class="d-sm-flex align-items-center justify-content-between mb-4 lw-page-header">
    <h1 class="h3 mb-0 text-gray-200">
        {{ __tr("Text to Speech") }}
    </h1>
    {{-- history button --}}
   <a class="btn btn-dark btn-sm lw-ajax-link-action lw-action-with-url" href="{{ route('manage.history',[
    'historyType' => 'text-to-speech'
]) }}"><i class="fa fa-history" aria-hidden="true"></i> <?= __tr('Text to Speech Generation History') ?></a>
   {{-- /history button --}}
</div>
<div class="row">
    <div class="col">
        @include('user.generator.partials.remaining-credits-partial', ['contentType' => 'speech'])
    </div>
</div>
<div class="row" x-data="{numberOfSpeechesRequested:1, showSpeechLoader:false}">
    <!-- Start of Page Wrapper -->
        <div class="col-md-4 mb-4">
            <!-- card -->
            <div class="card mb-4">
                <div class="card-body">
                    <form method="post" data-event-stream-update="true" action="{{ route('speech.generator.process') }}" class="lw-ajax-form lw-image-generator-block" data-pre-callback="onPreCallback" data-callback="onSuccessCallback" data-show-processing="true">
                    <div class="form-group">
                        <textarea type="text" class="form-control lw-image-generator-field" name="query" placeholder="{{ __tr("Text you want to generate speech for ...") }}" required></textarea>
                    </div>
                    <div class="form-group mt-2">
                        <label for="lwVoicePreset">
                            <?= __tr('Voice') ?>
                        </label>
                        <select name="speech_voice" class="form-control lw-ai-model-select custom-select" id="lwVoicePreset"
                            required>
                            @foreach (configItem('speech_voices') as $key => $voice)
                            <option value="{{ $key }}">{{ $voice }}</option>
                            @endforeach
                        </select>
                    </div>
                    <div class="form-group mt-2">
                        <label for="lwSpeedPreset">
                            <?= __tr('Speed') ?>
                        </label>
                        <select name="speech_speed" class="form-control lw-ai-model-select custom-select" id="lwSpeedPreset"
                            required>
                            @foreach (configItem('speech_speeds') as $key => $speed)
                            <option {{ ($key == '1.0') ? 'selected' : '' }} value="{{ $key }}">{{ $speed }}</option>
                            @endforeach
                        </select>
                    </div>
                        <div class="form-group">
                            <button type="submit" class="btn btn-light">
                                <?= __tr('Create') ?>
                            </button>
                        </div>
                </form>
                </div>
            </div>
            <!-- /card -->
        </div>
    <!-- End of Page Wrapper -->
    <div class="lw-generator-content col-md-8">
        <div x-data="{ aiGeneratedResponseError: '' }">
            <template x-if="aiGeneratedResponseError.length > 1">
                <div class="alert alert-danger alert-dismissible fade show" x-cloak x-text="aiGeneratedResponseError">
                </div>
            </template>
        </div>

        <div x-show="showSpeechLoader" class="row row-cols-1 row-cols-md-3 row-cols-lg-3 g-4" ></div>
        <div x-cloak x-show="!showSpeechLoader" class="row" x-data="{ audioFileUrl: '', recordUid: '' }">
                <h4 x-show="audioFileUrl" class="col-12 mt-5 text-center text-success">{{  __tr('Here is the Ai-generated voice audio.') }}</h4>
                <template x-if="audioFileUrl">
                    <div class="col-10 offset-1 mt-5 p-5">
                       <div class="lw-audio-player-container">
                        <audio width="100%" height="100%">
                            <source :src="audioFileUrl">{{ __tr('Your browser does not support the audio tag.') }}
                        </audio>
                       </div>
                      <div class="my-3 text-center col-12">
                        <a :href="__Utils.apiURL('<?= route('user.download.result_file', ['recordUid' => 'recordUid']) ?>', {'recordUid': recordUid})" class="btn btn-sm btn-secondary"><i class="fa fa-download"></i> {{  __tr('Download') }}</a>
                      </div>
                    </div>
                </template>
        </div>
    </div>
@lwPush('appScripts')
<script>
    "use strict";
    function onPreCallback(params) {
        __DataRequest.updateModels({
                showSpeechLoader:true,
                audioFileUrl:''
        });
        return params;
    }
    //callback response
    function onSuccessCallback(responseData) {
        if(responseData.reaction == 1) {
            __DataRequest.updateModels({
                showSpeechLoader:false,
                'audioFileUrl': responseData.data.audioFileUrl, //update array of responses
                'recordUid': responseData.data.recordUid, //update array of responses
            });
            _.defer(function() {
                GreenAudioPlayer.init({
                    selector: '.lw-audio-player-container',
                    stopOthersOnPlay: true,
                    showDownloadButton: true,
                });
            })
        }
    }
</script>
@lwPushEnd