<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

/*
|--------------------------------------------------------------------------
| Aigen Routes
|--------------------------------------------------------------------------
*/

Route::group([
    'namespace' => '\App\Yantrana\Components',
    'middleware' => 'common.entrance',
], function () {
    Route::get('/change-language/{localeID}', [
        'as' => 'locale.change',
        'uses' => 'Home\Controllers\HomeController@changeLocale',
    ]);

    // contact view
    Route::get('/contact', [
        'as' => 'user.read.contact',
        'uses' => 'User\Controllers\UserController@getContactView',
    ]);

    // process contact form
    Route::post('/post-contact', [
        'as' => 'user.contact.process',
        'uses' => 'User\Controllers\UserController@contactProcess',
    ]);

    // page preview
    Route::get('/page/{pageUId}/{title}', [
        'as' => 'page.preview',
        'uses' => 'Home\Controllers\HomeController@previewPage',
    ]);

    Route::get('/pricing', [
        'as' => 'pricing_page',
        'uses' => 'Home\Controllers\HomeController@pricingPage',
    ]);

    /*
    User Components Public Section Related Routes
    ----------------------------------------------------------------------- */
    Route::group(['middleware' => 'guest'], function () {
        Route::group([
            'namespace' => 'Home\Controllers',
        ], function () {
            // Get landing page view
            Route::get('/', [
                'as' => 'landing_page',
                'uses' => 'HomeController@landingPage',
            ]);
        });

        Route::group([
            'namespace' => 'User\Controllers',
            'prefix' => 'user',
        ], function () {
            // login
            Route::get('/login', [
                'as' => 'user.login',
                'uses' => 'UserController@login',
            ]);

            // login process
            Route::post('/login-process', [
                'as' => 'user.login.process',
                'uses' => 'UserController@loginProcess',
            ]);

            // User Registration
            Route::get('/sign-up', [
                'as' => 'user.sign_up',
                'uses' => 'UserController@signUp',
            ]);

            // User Registration Process
            Route::post('/sign-up-process', [
                'as' => 'user.sign_up.process',
                'uses' => 'UserController@signUpProcess',
            ]);

            // forgot password view
            Route::get('/forgot-password', [
                'as' => 'user.forgot_password',
                'uses' => 'UserController@forgotPasswordView',
            ]);

            // forgot password process
            Route::post('/forgot-password-process', [
                'as' => 'user.forgot_password.process',
                'uses' => 'UserController@processForgotPassword',
            ]);

            // reset password
            Route::get('/reset-password', [
                'as' => 'user.reset_password',
                'uses' => 'UserController@restPasswordView',
            ]);

            // reset password process
            Route::post('/reset-password-process/{reminderToken}', [
                'as' => 'user.reset_password.process',
                'uses' => 'UserController@processRestPassword',
            ]);

            // Account Activation
            Route::get('/{userUid}/account-activation', [
                'as' => 'user.account.activation',
                'uses' => 'UserController@accountActivation',
            ])->middleware('signed');

            // Login with otp view
            Route::get('/login-with-otp', [
                'as' => 'login.with.otp',
                'uses' => 'UserController@otpLoginView',
            ]);
            // send otp process
            Route::post('/send-otp', [
                'as' => 'send.otp',
                'uses' => 'UserController@sendOtp',
            ]);
            //verify otp
            Route::get('/verify-otp', [
                'as' => 'verify.otp',
                'uses' => 'UserController@verifyOtpView',
            ]);

            //verify otp process
            Route::post('/verify-otp-process', [
                'as' => 'verify.otp.process',
                'uses' => 'UserController@verifyOtp',
            ]);
        });
    });

    /*
    User Social Access Components Public Section Related Routes
    ----------------------------------------------------------------------- */
    Route::group([
        'namespace' => 'User\Controllers',
        'prefix' => 'user/social-login',
    ], function () {
        // social user login
        Route::get('/request/{provider}', [
            'as' => 'social.user.login',
            'uses' => 'SocialAccessController@redirectToProvider',
        ]);

        // social user login callback
        Route::get('/response/{provider}', [
            'as' => 'social.user.login.callback',
            'uses' => 'SocialAccessController@handleProviderCallback',
        ]);
    });

    /*
    After Authentication Accessible Routes
    -------------------------------------------------------------------------- */

    Route::group(['middleware' => 'auth'], function () {
        // dashboard page for logged in user
        Route::get('/dashboard', [
            'as' => 'dashboard_page',
            'uses' => 'Home\Controllers\HomeController@homePage',
        ]);
        // Get User Profile view
        Route::get('/@{username}', [
            'as' => 'user.profile_view',
            'uses' => 'User\Controllers\UserController@getUserProfile',
        ]);
        // Get user profile data
        Route::get('/{username}/get-user-profile-data', [
            'as' => 'user.get_profile_data',
            'uses' => 'User\Controllers\UserController@getUserProfileData',
        ]);

        // View photos settings
        Route::get('/update-log', [
            'as' => 'update.log',
            'uses' => 'User\Controllers\CreditWalletController@updateLog',
        ]);

        Route::post('/dashboard-user-data', [
            'as' => 'user.read.dashboard_data',
            'uses' => 'Home\Controllers\HomeController@getDashboardUserData',
        ]);


        /**
         * User Section
         *----------------------------------------------------------------------- */
        Route::group([
            'prefix' => 'user',
        ], function () {
            /**
             * User Component Related Routes
             *----------------------------------------------------------------------- */
            Route::group([
                'namespace' => 'User\Controllers',
            ], function () {
                // logout
                Route::get('/logout', [
                    'as' => 'user.logout',
                    'uses' => 'UserController@logout',
                ]);

                // change password view
                Route::get('/change-password', [
                    'as' => 'user.change_password',
                    'uses' => 'UserController@changePasswordView',
                ]);

                // User Change Password Process
                Route::post('/change-password-process', [
                    'as' => 'user.change_password.process',
                    'uses' => 'UserController@processChangePassword',
                ]);

                // change email view
                Route::get('/change-email', [
                    'as' => 'user.change_email',
                    'uses' => 'UserController@changeEmailView',
                ]);

                // User Change Email Process
                Route::post('/change-email-process', [
                    'as' => 'user.change_email.process',
                    'uses' => 'UserController@processChangeEmail',
                ]);

                // New Email Activation
                Route::get('/{userUid}/{newEmail}/new-email-activation', [
                    'as' => 'user.new_email.activation',
                    'uses' => 'UserController@newEmailActivation',
                ]);

                // Get User Profile view
                Route::get('/update-email-success', [
                    'as' => 'user.new_email.read.success',
                    'uses' => 'UserController@updateEmailSuccessView',
                ]);

                // post report user
                Route::post('/{sendUserUId}/report-user', [
                    'as' => 'user.write.report_user',
                    'uses' => 'UserController@reportUser',
                ]);

                // Permanent delete account
                Route::post('/delete-account', [
                    'as' => 'user.write.delete_account',
                    'uses' => 'UserController@deleteAccount',
                ]);
            });

            // User Settings related routes
            Route::group([
                'namespace' => 'UserSetting\Controllers',
                'prefix' => 'settings',
            ], function () {
                // View settings
                Route::get('/{pageType}', [
                    'as' => 'user.read.setting',
                    'uses' => 'UserSettingController@getUserSettingView',
                ]);
                // Process Configuration Data
                Route::post('/{pageType}/process-user-setting-store', [
                    'as' => 'user.write.setting',
                    'uses' => 'UserSettingController@processStoreUserSetting',
                ]);
                // Process basic settings
                Route::post('/process-basic-settings', [
                    'as' => 'user.write.basic_setting',
                    'uses' => 'UserSettingController@processUserBasicSetting',
                ]);

                // Process location / maps data
                Route::post('/search-static-cities', [
                    'as' => 'user.read.search_static_cities',
                    'uses' => 'UserSettingController@searchStaticCities',
                ]);

                // Store User Profile Image
                Route::post('/upload-profile-image', [
                    'as' => 'user.upload_profile_image',
                    'uses' => 'UserSettingController@uploadProfileImage',
                ]);

            });
        });
        /**
         * User Section End here
         *----------------------------------------------------------------------- */

        /**
         * Generation and other Routes
         */
        Route::group([
            'namespace' => 'Prompt\Controllers',
            'prefix' => 'templates',
        ], function () {
            Route::get('/{category?}', [
                'as' => 'templates.display_list',
                'uses' => 'PromptController@getTemplateData',
            ]);
            Route::get('/generate/{promptKey}', [
                'as' => 'text.generation.page',
                'uses' => 'PromptController@textGenerationPageView',
            ]);
        });

        /**
         * Text Generation Components Public Section Related Routes
         *----------------------------------------------------------------------- */
        Route::group([
            'namespace' => 'Prompt\Controllers',
            'prefix' => 'ai-assistant',
        ], function () {
            //text generation view
            Route::get('/{contentType?}', [
                'as' => 'text.generation.view',
                'uses' => 'PromptController@show',
            ])->whereIn('contentType', [
                        'text',
                        'code',
                        'translation'
                    ]);
            ;
            //text generation process
            Route::post('/text/generate-process', [
                'as' => 'text.generator.process',
                'uses' => 'PromptController@textGeneratorProcess',
            ]);

            Route::get('/code', [
                'as' => 'code.generation.view',
                'uses' => 'PromptController@codeGenerationView',
            ]);

            Route::get('/image', [
                'as' => 'image.generation.view',
                'uses' => 'PromptController@imageGeneratorView',
            ]);

            Route::post('/image/generate-process', [
                'as' => 'image.generator',
                'uses' => 'PromptController@imageGeneratorProcess',
            ]);

            Route::get('/speech', [
                'as' => 'speech.generation.view',
                'uses' => 'PromptController@speechGeneratorView',
            ]);

            Route::post('/speech/generate-process', [
                'as' => 'speech.generator.process',
                'uses' => 'PromptController@speechGeneratorProcess',
            ]);

            //animated image generation
            Route::group([
                'prefix' => '/image-to-depth-animation',
            ], function () {
                Route::get('/', [
                    'as' => 'image.conversion_animation.view',
                    'uses' => 'PromptController@imageAnimationView',
                ]);
                // Store temp image on the server
                Route::post('/upload-source-image', [
                    'as' => 'user.upload_source_animation_image',
                    'uses' => 'PromptController@uploadSourceAnimationImage',
                ]);
                // 
                Route::post('/image-to-depth-animation/process', [
                    'as' => 'image.conversion_animation.process',
                    'uses' => 'PromptController@processSourceAnimationImage',
                ]);
            });
            /**
             * Speech To Text Generation Public Section Related Routes
             *----------------------------------------------------------------------- */
            Route::get('/speech-to-text', [
                'as' => 'speech_to_text.read.view',
                'uses' => 'PromptController@speechToTextView',
            ]);

            // Store User Profile Image
            Route::post('/speech-to-text/upload-audio', [
                'as' => 'user.upload_speech_audio',
                'uses' => 'PromptController@uploadSpeechAudio',
            ]);

            Route::get('/download/{recordUid}/{filename?}', [
                'as' => 'user.download.result_file',
                'uses' => 'PromptController@downloadResultFile',
            ]);

        });

        /**
         * Manage History Public Section Related Routes
         *----------------------------------------------------------------------- */
        Route::group([
            'namespace' => 'Prompt\Controllers',
            'prefix' => 'history',
        ], function () {
            Route::get('{historyType}', [
                'as' => 'manage.history',
                'uses' => 'PromptController@historyView',
            ]);

            // Get users referred
            Route::get('/history-list/{historyType}', [
                'as' => 'user.history.list',
                'uses' => 'PromptController@getUserHistoryList',
            ]);

            // Post users history
            Route::post('/{historyUId}/delete-history', [
                'as' => 'user.history.write.delete',
                'uses' => 'PromptController@processDeleteHistory',
            ]);
        });

        /**
         * Credit wallet User Components Public Section Related Routes
         *----------------------------------------------------------------------- */
        Route::group([
            'namespace' => 'User\Controllers',
            'prefix' => 'credit-wallet',
        ], function () {
            // User Credit-wallet View
            Route::get('/', [
                'as' => 'user.credit_wallet.read.view',
                'uses' => 'CreditWalletController@creditWalletView',
            ]);

            // User Credit-wallet balance enquire
            Route::get('/balance-enquiry', [
                'as' => 'user.credit_wallet_balance.read.view',
                'uses' => 'CreditWalletController@creditWalletBalanceEnquiry',
            ]);

            // User wallet-transactions View
            Route::get('/transactions', [
                'as' => 'user.wallet.transactions.read.view',
                'uses' => '\App\Yantrana\Components\User\Controllers\CreditWalletController@walletTransactionsView',
            ]);

            // Public User Wallet transaction list
            Route::get('/user-wallet-transaction-list', [
                'as' => 'user.credit_wallet.read.wallet_transaction_list',
                'uses' => 'CreditWalletController@getUserWalletTransactionList',
            ]);

            // paypal transaction complete
            Route::post('/{packageUid}/paypal-transaction-complete', [
                'as' => 'user.credit_wallet.write.paypal_transaction_complete',
                'uses' => 'CreditWalletController@paypalTransactionComplete',
            ]);

            Route::post('/paypal-order-submit', [
                'as' => 'paypal.order.process',
                'uses' => 'CreditWalletController@submitPaypalOrderProcess',
            ]);

            Route::post('/paypal/capture-paypal-order', [
                'as' => 'capture.paypal.checkout',
                'uses' => 'CreditWalletController@capturePaypalOrder',
            ]);

            // stripe checkout routes
            Route::post('/payment-process', [
                'as' => 'user.credit_wallet.write.payment_process',
                'uses' => 'CreditWalletController@paymentProcess',
            ]);

            // stripe success callback routes
            Route::get('/stripe-callback', [
                'as' => 'user.credit_wallet.write.stripe.callback_url',
                'uses' => 'CreditWalletController@stripeCallbackUrl',
            ]);

            // stripe checkout cancel url
            Route::get('/stripe-cancel', [
                'as' => 'user.credit_wallet.write.stripe.cancel_url',
                'uses' => 'CreditWalletController@stripeCancelCallback',
            ]);

            // razorpay checkout
            Route::post('/razorpay-checkout', [
                'as' => 'user.credit_wallet.write.razorpay.checkout',
                'uses' => 'CreditWalletController@razorpayCheckout',
            ]);

            // coingate checkout
            Route::post('/coingate-checkout', [
                'as' => 'user.credit_wallet.write.coingate.checkout',
                'uses' => 'CreditWalletController@coingateCheckout',
            ]);

            // coingate url routes
            Route::get('/coingate-success-url/{status}', [
                'as' => 'user.credit_wallet.coingate.success',
                'uses' => 'CreditWalletController@coingateSuccessOrFailUrl',
            ]);
        });

        Route::group([
            'namespace' => 'User\Controllers',
            'prefix' => 'user/refer-and-earn',
        ], function () {

            Route::get('/', [
                'as' => 'manage.referral',
                'uses' => 'ReferralController@referralView',
            ]);

            // Get users referred
            Route::get('/referral-list', [
                'as' => 'user.referral.read.list',
                'uses' => 'ReferralController@getReferralList',
            ]);
        });

        // Generation and other routes end

        /**
         * Manage / Admin Section
         *----------------------------------------------------------------------- */
        Route::group([
            'middleware' => 'admin.auth',
            'prefix' => 'admin',
        ], function () {
            /**
             * Manage User Components Public Section Related Routes
             *----------------------------------------------------------------------- */
            Route::group([
                'namespace' => 'User\Controllers',
                'prefix' => 'manage/user',
            ], function () {
                // Manage User List
                Route::get('/{status}/list', [
                    'as' => 'manage.user.view_list',
                    'uses' => 'ManageUserController@userList',
                ]);

                // Manage User List
                Route::get('/{status}/users-list', [
                    'as' => 'manage.user.read.list',
                    'uses' => 'ManageUserController@userDataTableList',
                ]);

                // Add New User
                Route::get('/add', [
                    'as' => 'manage.user.add',
                    'uses' => 'ManageUserController@addNewUserView',
                ]);
                // Add New User Process
                Route::post('/process-add', [
                    'as' => 'manage.user.write.create',
                    'uses' => 'ManageUserController@processAddNewUser',
                ]);
                // Update User
                Route::post('/{userUid}/process-update', [
                    'as' => 'manage.user.write.update',
                    'uses' => 'ManageUserController@processUpdateUser',
                ]);
                // Soft Delete User
                Route::post('/{userUid}/process-soft-delete', [
                    'as' => 'manage.user.write.soft_delete',
                    'uses' => 'ManageUserController@processUserSoftDelete',
                ]);
                // Permanent  Delete User
                Route::post('/{userUid}/process-permanent-delete', [
                    'as' => 'manage.user.write.permanent_delete',
                    'uses' => 'ManageUserController@processUserPermanentDelete',
                ]);
                // Restore User
                Route::post('/{userUid}/process-restore-user', [
                    'as' => 'manage.user.write.restore_user',
                    'uses' => 'ManageUserController@processRestoreUser',
                ]);
                // Blocked User
                Route::post('/{userUid}/process-block-user', [
                    'as' => 'manage.user.write.block_user',
                    'uses' => 'ManageUserController@processUserBlock',
                ]);
                // Unblocked User
                Route::post('/{userUid}/process-unblock-user', [
                    'as' => 'manage.user.write.unblock_user',
                    'uses' => 'ManageUserController@processUserUnblock',
                ]);
                // Show User Details
                Route::get('/{userUid}/details', [
                    'as' => 'manage.user.read.details',
                    'uses' => 'ManageUserController@getUserDetails',
                ]);

                // Manage User transaction list
                Route::get('/{userUid}/manage-user-transaction-list', [
                    'as' => 'manage.user.read.transaction_list',
                    'uses' => 'ManageUserController@manageUserTransactionList',
                ]);

                // Manage User transaction list
                Route::post('/add-user-allocate-credits', [
                    'as' => 'manage.user.write.allocate_credits',
                    'uses' => 'ManageUserController@addUserAllocateCredits',
                ]);
            });

            /**
             * Manage Referral Components Public Section Related Routes
             *----------------------------------------------------------------------- */
            Route::group([
                'namespace' => 'User\Controllers',
                'prefix' => 'manage/referral',
            ], function () {
                // Get users referred
                Route::get('/referral-users-list', [
                    'as' => 'manage.referral.system',
                    'uses' => 'ReferralController@referralUsersReadList',
                ]);

                // Get users referred
                Route::get('/all-referral-read-list', [
                    'as' => 'all.referral.read.list',
                    'uses' => 'ReferralController@getAllReferralDataTableList',
                ]);
            });

            /**
             * Manage History On Public Section Related Routes
             *----------------------------------------------------------------------- */
            Route::group([
                'namespace' => 'Prompt\Controllers',
                'prefix' => 'manage-history',
            ], function () {
                Route::get('/{historyType}/list', [
                    'as' => 'manage.users.history',
                    'uses' => 'PromptController@manageUsersHistoryView',
                ]);
                Route::get('/get-all-users-history-list/{historyType}', [
                    'as' => 'all.users.history.list',
                    'uses' => 'PromptController@manageAllUsersHistoryList',
                ]);

                // delete users history
                Route::post('/{historyUId}/delete-history', [
                    'as' => 'admin.history.write.delete',
                    'uses' => 'PromptController@processDeleteHistory',
                ]);

            });

            /**
             * Manage Credit Package Routes
             *----------------------------------------------------------------------- */
            Route::group([
                'namespace' => 'CreditPackage\Controllers',
                'prefix' => 'manage/credit-package',
            ], function () {
                // credit_package list view
                Route::get('/list', [
                    'as' => 'manage.credit_package.read.list',
                    'uses' => 'CreditPackageController@getCreditPackageList',
                ]);

                // credit_package add view
                Route::get('/add-package', [
                    'as' => 'manage.credit_package.add.view',
                    'uses' => 'CreditPackageController@packageAddView',
                ]);

                // credit_package add process
                Route::post('/add-package-process', [
                    'as' => 'manage.credit_package.write.add',
                    'uses' => 'CreditPackageController@addPackage',
                ]);

                // Package edit view
                Route::get('/{packageUId}/edit-package', [
                    'as' => 'manage.credit_package.edit.view',
                    'uses' => 'CreditPackageController@packageEditView',
                ]);

                // Package edit process
                Route::post('/{packageUId}/edit-package-process', [
                    'as' => 'manage.credit_package.write.edit',
                    'uses' => 'CreditPackageController@editPackage',
                ]);

                // Package delete view
                Route::post('/{packageUId}/delete-package', [
                    'as' => 'manage.credit_package.write.delete',
                    'uses' => 'CreditPackageController@processDeletePackage',
                ]);
            });

            /**
             * Media Component Routes Start from here
             *------------------------------------------------------------------- */
            Route::group([
                'namespace' => 'Media\Controllers',
                'prefix' => 'media',
            ], function () {
                // Temp Upload
                Route::post('/upload-temp-media', [
                    'as' => 'media.upload_temp_media',
                    'uses' => 'MediaController@uploadTempMedia',
                ]);
                // Package Temp Upload
                Route::post('/upload-package-temp-media', [
                    'as' => 'media.package.upload_temp_media',
                    'uses' => 'MediaController@uploadPackageTempMedia',
                ]);
                // Upload Logo
                Route::post('/upload-logo', [
                    'as' => 'media.upload_logo',
                    'uses' => 'MediaController@uploadLogo',
                ]);
                // Upload Small Logo
                Route::post('/upload-small-logo', [
                    'as' => 'media.upload_small_logo',
                    'uses' => 'MediaController@uploadSmallLogo',
                ]);
                // Upload Favicon
                Route::post('/upload-favicon', [
                    'as' => 'media.upload_favicon',
                    'uses' => 'MediaController@uploadFavicon',
                ]);
            });

            /**
             * Dashboard Component Routes Start from here
             *------------------------------------------------------------------- */
            Route::group([
                'namespace' => 'Dashboard\Controllers',
            ], function () {
                // dashboard view
                Route::get('/', [
                    'as' => 'manage.dashboard',
                    'uses' => 'DashboardController@loadDashboardView',
                ]);
                Route::post('/admin-dashboard-data', [
                    'as' => 'admin.read.dashboard_data',
                    'uses' => 'DashboardController@getDashboardAdminData',
                ]);
            });

            /**
             * Configuration Component Routes Start from here
             *------------------------------------------------------------------- */
            Route::group([
                'namespace' => 'Configuration\Controllers',
                'prefix' => 'configuration',
            ], function () {

                // Clear Cache Everything
                Route::get('/licence-information', [
                    'as' => 'manage.configuration.product_registration',
                    'uses' => 'ConfigurationController@registerProductView',
                ]);

                Route::post('/licence-information-process', [
                    'as' => 'installation.version.create.registration',
                    'uses' => 'ConfigurationController@processProductRegistration',
                ]);

                Route::post('/licence-information-remove-process', [
                    'as' => 'installation.version.create.remove_registration',
                    'uses' => 'ConfigurationController@processProductRegistrationRemoval',
                ]);

                // Clear Cache Everything
                Route::get('/clear-system-cache', [
                    'as' => 'manage.configuration.clear_cache',
                    'uses' => 'ConfigurationController@clearSystemCache',
                ]);

                // View Configuration View
                Route::get('/{pageType}', [
                    'as' => 'manage.configuration.read',
                    'uses' => 'ConfigurationController@getConfiguration',
                ]);
                // Process Configuration Data
                Route::post('/{pageType}/process-configuration-store', [
                    'as' => 'manage.configuration.write',
                    'uses' => 'ConfigurationController@processStoreConfiguration',
                ]);

            });

            Route::group([
                'namespace' => 'Configuration\Controllers',
                'prefix' => 'view-references',
            ], function () {
                // View help View
                Route::get('/', [
                    'as' => 'manage.help.read',
                    'uses' => 'ConfigurationController@emailTemplateView',
                ]);
            });
            /**
             * Manage Financial transaction Components Manage Section Related Routes
             *----------------------------------------------------------------------- */
            Route::group([
                'namespace' => 'FinancialTransaction\Controllers',
                'prefix' => 'financial-transaction',
            ], function () {
                //Manage Financial transaction transaction View
                Route::get('/{transactionType}/list', [
                    'as' => 'manage.financial_transaction.read.view_list',
                    'uses' => 'FinancialTransactionController@financialTransactionViewList',
                ]);

                // Financial transaction list
                Route::get('/{transactionType}/transaction-list', [
                    'as' => 'manage.financial_transaction.read.list',
                    'uses' => 'FinancialTransactionController@getTransactionList',
                ]);

                // Delete all test transaction
                Route::post('/delete-all-test-transaction', [
                    'as' => 'manage.financial_transaction.write.delete.all_transaction',
                    'uses' => 'FinancialTransactionController@deleteAllTestTransaction',
                ]);
            });

            /**
             * Pages Components Manage Section Related Routes
             *------------------------------------------------------------------- */
            Route::group([
                'namespace' => 'Pages\Controllers',
                'prefix' => 'pages',
            ], function () {
                // pages view
                Route::get('/', [
                    'as' => 'manage.page.view',
                    'uses' => 'ManagePagesController@pageListView',
                ]);

                // pages view
                Route::get('/list', [
                    'as' => 'manage.page.list',
                    'uses' => 'ManagePagesController@getDatatableData',
                ]);

                // pages add view
                Route::get('/add', [
                    'as' => 'manage.page.add.view',
                    'uses' => 'ManagePagesController@pageAddView',
                ]);

                // pages add process
                Route::post('/page-add-process', [
                    'as' => 'manage.page.write.add',
                    'uses' => 'ManagePagesController@processAddPage',
                ]);

                // pages edit view
                Route::get('/{pageUId}/edit', [
                    'as' => 'manage.page.edit.view',
                    'uses' => 'ManagePagesController@pageEditView',
                ]);

                // pages edit process
                Route::post('/{pageUId}/page-edit-process', [
                    'as' => 'manage.page.write.edit',
                    'uses' => 'ManagePagesController@processEditPage',
                ]);

                // pages delete process
                Route::post('/{pageUId}/page-delete', [
                    'as' => 'manage.page.write.delete',
                    'uses' => 'ManagePagesController@delete',
                ]);
            });

            /**
             * Manage Translations
             *------------------------------------------------------------------- */
            Route::group([
                'namespace' => 'Translation\Controllers',
                'prefix' => 'translations',
            ], function () {
                Route::get('/', [
                    'as' => 'manage.translations.languages',
                    'uses' => 'TranslationController@languages',
                ]);

                // Store New Language
                Route::post('/process-language-store', [
                    'as' => 'manage.translations.write.language_create',
                    'uses' => 'TranslationController@storeLanguage',
                ]);

                // Update Language
                Route::post('/process-language-update', [
                    'as' => 'manage.translations.write.language_update',
                    'uses' => 'TranslationController@updateLanguage',
                ]);

                // Delete Language
                Route::post('/{languageId}/process-language-delete', [
                    'as' => 'manage.translations.write.language_delete',
                    'uses' => 'TranslationController@deleteLanguage',
                ]);
                //language list
                Route::get('language/{languageId}', [
                    'as' => 'manage.translations.lists',
                    'uses' => 'TranslationController@lists',
                ]);
                //scan language
                Route::post('/scan/{languageId}/{preventReload?}', [
                    'as' => 'manage.translations.scan',
                    'uses' => 'TranslationController@scan',
                ]);
                //update 
                Route::post('/update', [
                    'as' => 'manage.translations.update',
                    'uses' => 'TranslationController@update',
                ]);
                //export to excel
                Route::get('/export/{languageId}', [
                    'as' => 'manage.translations.export',
                    'uses' => 'TranslationController@export',
                ]);
                //import to excel
                Route::post('/import/{languageId}', [
                    'as' => 'manage.translations.import',
                    'uses' => 'TranslationController@import',
                ]);
                Route::post('/auto-translate/{serviceId}/{languageId}', [
                    'as' => 'manage.translations.auto_translate',
                    'uses' => 'TranslationController@translatePoFile',
                ]);
                Route::post('/auto-translate-all/{serviceId}', [
                    'as' => 'manage.translations.auto_translate_all',
                    'uses' => 'TranslationController@translatePoFiles',
                ]);
            });

            /**
             * Templates and other Routes
             */
            Route::group([
                'namespace' => 'Prompt\Controllers',
                'prefix' => 'manage/templates',
            ], function () {
                Route::get('/download-template-collection-file', [
                    'as' => 'template.file.download.read',
                    'uses' => 'PromptTemplateController@downloadCurrentTemplateFile',
                ]);
                //reset to default template
                Route::post('/reset-template-collection-file', [
                    'as' => 'template.file.default_reset.write',
                    'uses' => 'PromptTemplateController@resetToDefaultTemplates',
                ]);
                //merge default template
                Route::post('/merge-template-collection-file', [
                    'as' => 'template.file.merge_default_reset.write',
                    'uses' => 'PromptTemplateController@mergeDefaultTemplates',
                ]);
                //show template category
                Route::get('/categories-list', [
                    'as' => 'categories.list',
                    'uses' => 'PromptTemplateController@categoriesListView',
                ]);
                //add new category
                Route::post('/category-write-create', [
                    'as' => 'category.write.create',
                    'uses' => 'PromptTemplateController@createNewCategory',
                ]);
                //edit category
                Route::get('/category-templates/{category}', [
                    'as' => 'get.category.templates',
                    'uses' => 'PromptTemplateController@getCategoryTemplate',
                ]);
                //update category
                Route::post('/category-write-update', [
                    'as' => 'manage.category.write.update',
                    'uses' => 'PromptTemplateController@updateCategory',
                ]);
                //delete category
                Route::post('/category-write-delete/{categoryId}', [
                    'as' => 'manage.category.write.delete',
                    'uses' => 'PromptTemplateController@deleteCategory',
                ]);
                //create new  template
                Route::post('/create-new-template', [
                    'as' => 'manage.template.write.create',
                    'uses' => 'PromptTemplateController@createTemplate',
                ]);
                //update new template
                Route::post('/update-write-template', [
                    'as' => 'manage.template.write.update',
                    'uses' => 'PromptTemplateController@updateTemplate',
                ]);
                // edit template
                Route::get('/prepare-template-data/{templateId}/{categoryId}', [
                    'as' => 'edit.template.data',
                    'uses' => 'PromptTemplateController@editTemplate',
                ]);
                //delete template
                Route::post('/template-write-delete/{categoryId}/{templateId}', [
                    'as' => 'manage.template.write.delete',
                    'uses' => 'PromptTemplateController@deleteTemplate',
                ]);
            });
        });
    });

    // coingate success callback routes
    Route::post('/coingate-callback', [
        'as' => 'user.credit_wallet.write.coingate.callback_url',
        'uses' => '\App\Yantrana\Components\User\Controllers\CreditWalletController@coingateCallbackUrl',
    ]);

    /**
     * webhook->Signing secret->Click reveal
     */
    Route::post('/stripe/order-payment-webhook', [
        'as' => 'stripe-webhook',
        'uses' => '\App\Yantrana\Components\User\Controllers\CreditWalletController@handleOrderPaymentStripeWebhook',
    ]);

    Route::post('/razorpay/order-payment-razorpay-webhook', [
        'as' => 'razorpay-webhook',
        'uses' => '\App\Yantrana\Components\User\Controllers\CreditWalletController@handleOrderPaymentRazorpayWebhook'
    ]);
    //user referral system
    Route::get('/referral', [
        'as' => 'referral-url',
        'uses' => '\App\Yantrana\Components\User\Controllers\ReferralController@registerReferralUser'
    ]);
    Route::get('/user/{type}', [
        'as' => 'terms.conditions',
        'uses' => '\App\Yantrana\Components\User\Controllers\UserController@termsAndConditions'
    ]);
    //ghhghghghghhgg
});
